@@ -259,7 +259,12 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
 				break;
 			}
 								
-			DRAWITEMSTRUCT* dis = (DRAWITEMSTRUCT*)lParam;			
+			DRAWITEMSTRUCT* dis = (DRAWITEMSTRUCT*)lParam;
+			if((UT_sint32)dis->itemData < 0)
+			{
+				return TRUE;
+			}
+			
 			XAP_Toolbar_ControlFactory * pFactory = t->m_pWin32App->getControlFactory();			
 
 			if (!t->m_pFontCtrl)
@@ -1055,9 +1060,6 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 				EV_Toolbar_Control * pControl = pFactory->getControl(t, AP_TOOLBAR_ID_FMT_STYLE);			
 				const UT_Vector * v = pControl->getContents();				
 					
-				AP_Win32Toolbar_StyleCombo * pStyleC = static_cast<AP_Win32Toolbar_StyleCombo *>(pControl);
-				pStyleC->repopulate();	
-				
 				//
 				// Is this a valid text?
 				//
