@@ -17,6 +17,7 @@
  * 02111-1307, USA.
  */
 
+#include <glib.h>
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkmain.h>
 #include <gdk/gdkrgb.h>
@@ -38,65 +39,72 @@
 #include "xap_UnixApp.h"
 #include "xap_FakeClipboard.h"
 #include "gr_UnixImage.h"
-#include "xap_UnixFrame.h"
 #include "xap_UnixToolbar_Icons.h"
 #include "xap_Unix_TB_CFactory.h"
 #include "xap_Prefs.h"
 #include "xap_UnixEncodingManager.h"
+
+#ifndef WITH_PANGO
 #include "xap_UnixFontManager.h"
+#endif
+
 #include "xap_UnixNullGraphics.h"
+UnixNull_Graphics * abi_unixnullgraphics_instance = 0;
 
 /*****************************************************************/
+// #include <sys/time.h> // tmp just to measure the time that XftInit takes
 
 XAP_UnixApp::XAP_UnixApp(XAP_Args * pArgs, const char * szAppName)
 	: XAP_App(pArgs, szAppName), m_dialogFactory(this), m_controlFactory()
 {
+	XftInit(NULL);
+
 	m_pUnixToolbarIcons = 0;
 
 	_setAbiSuiteLibDir();
 
 	memset(&m_geometry, 0, sizeof(m_geometry));
 
-	m_bBonoboRunning = false;
-	// hack to ensure UnixNull_Graphics is linked properly
-	// this condition should be false always
-	if (this == 0)
-	{
-		UnixNull_Graphics * pUN_G = new UnixNull_Graphics(0,0);
-	}
+
+	/* We need to link UnixNull_Graphics because the AbiCommand
+	 * plugin uses it.
+	 */
+	if (abi_unixnullgraphics_instance)
+	  {
+	    delete abi_unixnullgraphics_instance;
+	    abi_unixnullgraphics_instance = new UnixNull_Graphics(0,0);
+	  }
 }
 
 XAP_UnixApp::~XAP_UnixApp()
 {
 	DELETEP(m_pUnixToolbarIcons);
-	DELETEP(m_fontManager);
+
+#ifndef WITH_PANGO
+	delete m_fontManager;
+#endif	
 }
 
-bool XAP_UnixApp::initialize()
+bool XAP_UnixApp::initialize(bool have_display)
 {
+	if (!g_thread_supported ()) g_thread_init (NULL);
+
 	// let our base class do it's thing.
 	
 	XAP_App::initialize();
 
 	/*******************************/
 
+#ifndef WITH_PANGO	
 	// load the font stuff from the font directory
-
+	UT_DEBUGMSG(("Loading Fonts\n"));
 	if (!_loadFonts())
 		return false;
+	UT_DEBUGMSG(("Fonts Loaded \n"));
+#endif
 	
 	/*******************************/
-
-	// set up new widgets so that they work well with gdkrgb functions
-	//gtk_widget_push_visual(gtk_preview_get_visual());
-	//gtk_widget_push_colormap(gtk_preview_get_cmap());
-
-	gdk_rgb_init();
-	gtk_widget_set_default_colormap(gdk_rgb_get_cmap());
-	gtk_widget_set_default_visual(gdk_rgb_get_visual());
-
-	/*******************************/
-  
+	
 	// load only one copy of the platform-specific icons.
 	
 	m_pUnixToolbarIcons = new AP_UnixToolbar_Icons();
@@ -126,10 +134,12 @@ XAP_Toolbar_ControlFactory * XAP_UnixApp::getControlFactory()
 	return &m_controlFactory;
 }
 
+#ifndef WITH_PANGO
 XAP_UnixFontManager * XAP_UnixApp::getFontManager()
 {
 	return m_fontManager;
 }
+#endif
 
 void XAP_UnixApp::setWinGeometry(int x, int y, UT_uint32 width, UT_uint32 height,
 								 UT_uint32 flags)
@@ -180,92 +190,29 @@ const char * XAP_UnixApp::getUserPrivateDirectory()
 	return buf;
 }
 
+#ifndef WITH_PANGO
 bool XAP_UnixApp::_loadFonts()
 {
 	// create a font manager for our app to use
-	UT_uint32 relativePathsSoFar = 0, relativePathCount = 0;
-	UT_uint32 i = 0;
-	
 	m_fontManager = new XAP_UnixFontManager();
+	XAP_UnixFontManager::pFontManager = m_fontManager; // set the static variable pFontManager, so we can access our fontmanager from a static context
 	UT_ASSERT(m_fontManager);
 
-	// find all the fonts in the appropriate places.  the list of directories
-	// is given in a preferences variable.
-
-	char * szTemp = NULL;
-	const char * szPrefFontPath = NULL;
-	getPrefsValue(XAP_PREF_KEY_UnixFontPath,
-		      (const XML_Char**)&szPrefFontPath);
-	UT_ASSERT((szPrefFontPath) && (*szPrefFontPath));
-
- 	for (i = 0; szPrefFontPath[i]; i++)
-  	{
-  		// count the number of segments in the path
-  		// path looks like: "/font/dir;dir/anotherdir;/more/fonts"
-  		if( ((i == 0) || (szPrefFontPath[i-1] == ';')) && (szPrefFontPath[i] != '/'))
-  			relativePathCount++;
-  	}
-  	
-  	// cache the suiteDir's name and length instead of calculating
-  	// them on every loop
-	char * suiteDirCache = (char *)getAbiSuiteLibDir();
-  	UT_uint32 suiteLenCache = strlen(suiteDirCache);
-
- 	// make pointer to the font path. ignore the cast to make gcc shut up
-	char *szPrefFontPathPtr = (char *)szPrefFontPath;
-
-	for (i = 0; szPrefFontPathPtr[i]; i++)
- 		if ( ((i == 0) || (szPrefFontPathPtr[i-1] == ';')) && (szPrefFontPathPtr[i] != '/'))
- 		{
-		        // if relative path in prefs, prepend library directory.
- 			szTemp = (char *)UT_calloc(suiteLenCache + strlen(szPrefFontPathPtr) + 10, sizeof(char));
- 			strcpy(szTemp, szPrefFontPathPtr);
- 			sprintf(szTemp + i, "%s/%s", suiteDirCache, szPrefFontPathPtr + i);
- 			
- 			// if relativePathsSoFar > 1 then szPrefFontPathPtr
- 			// was really szTemp and was allocated by our call to
- 			// UT_calloc so we must free it. also, we are sure not to
-			// free the memory pointed to by getPrefsValue()
- 			if (relativePathsSoFar && szPrefFontPathPtr)
- 				free(szPrefFontPathPtr);
- 			
- 			szPrefFontPathPtr = szTemp;
- 			relativePathsSoFar++;
- 		}
- 
- 	// HUH? These don't match somehow. Abort!!
- 	UT_ASSERT(relativePathsSoFar == relativePathCount);
-	//UT_DEBUGMSG(("Using FontPath from preferences [%s].\n",szPrefFontPathPtr));
-	m_fontManager->setFontPath(szPrefFontPathPtr);
-	FREEP(szTemp);
-	
 	// let it loose
-
+	UT_DEBUGMSG(("Scavange Fonts started \n"));
 	if (!m_fontManager->scavengeFonts())
 		return false;
 	
-#if 0
-#ifdef DEBUG
-	XAP_UnixFont ** fonts = m_fontManager->getAllFonts();
-	UT_DEBUGMSG(("Found Fonts:\n"));
-	for (i = 0; i < m_fontManager->getCount(); i++)
-	{
-		UT_DEBUGMSG(("\tName [%s] at [%s], metrics [%s]\n",
-					 fonts[i]->getName(), fonts[i]->getFontfile(),
-					 fonts[i]->getMetricfile()));
-	}
-
-	DELETEP(fonts);
-#endif
-#endif
-
+	UT_DEBUGMSG(("Scavange Fonts finished \n"));
 	return true;
 }
+#endif //#ifndef WITH_PANGO
 
 void XAP_UnixApp::_setAbiSuiteLibDir()
 {
+	// FIXME: this code sucks hard
+
 	char buf[PATH_MAX];
-//	char buf2[PATH_MAX]; // not used?
 
 	// see if a command line option [-lib <AbiSuiteLibraryDirectory>] was given
 
@@ -305,15 +252,9 @@ void XAP_UnixApp::_setAbiSuiteLibDir()
 		return;
 	}
 
-	// TODO what to do ??  try the current directory...
-	
-	UT_DEBUGMSG(("ABISUITE_HOME not set and -lib not given.  Assuming current directory....\n"));
+	// otherwise, use the hard-coded value
+	XAP_App::_setAbiSuiteLibDir(getAbiSuiteHome());
 
-	getcwd(buf,sizeof(buf));
-	int len = strlen(buf);
-	if (buf[len-1]=='/')				// trim trailing slash
-		buf[len-1] = 0;
-	XAP_App::_setAbiSuiteLibDir(buf);
 	return;
 }
 
