@@ -160,7 +160,7 @@ UT_uint32 PS_Graphics::getFontDescent()
 }
 
 
-void PS_Graphics::getCoverage(UT_Vector& coverage)
+void PS_Graphics::getCoverage(UT_NumberVector& coverage)
 {
 	UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 }
@@ -1155,14 +1155,16 @@ void PS_Graphics::drawRGBImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDest)
 			image->width, image->height * -1, image->height);
 	m_ps->writeBytes(buf);
 	
-	g_snprintf(buf, sizeof (buf),"{currentfile\n  rowdata readhexstring pop}\nfalse 3\ncolorimage\n");
+	int byteWidth = (pPSImage->getHasAlpha() ? 4 : 3);
+
+	g_snprintf(buf, sizeof (buf),"{currentfile rowdata readhexstring pop}\nfalse %d colorimage\n", byteWidth);
 	m_ps->writeBytes(buf);
 	
 	// "image" is full of 24 bit data; throw the data specifications
 	// and then the raw data (in hexadeicmal) into the file.
 	UT_Byte * start = image->data;
 	UT_Byte * cursor = NULL;
-	UT_Byte * end = start + image->width * image->height * 3; // 3 bytes per pixel
+	UT_Byte * end = start + image->width * image->height * byteWidth;
 	UT_Byte hexbuf[3];
 	int col;
 	for (cursor = start, col = 0 ; cursor < end; cursor++, col++)
@@ -1174,8 +1176,7 @@ void PS_Graphics::drawRGBImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDest)
 		if (col == 40) // 2 chars per round, 80 columns total
 		{
 			col = -1;
-			g_snprintf(reinterpret_cast<char *>(&hexbuf[0]), sizeof(hexbuf), "\n");
-			m_ps->writeBytes(hexbuf, 1);
+			m_ps->writeBytes("\n", 1);
 		}
 	}
 	g_snprintf(buf, sizeof(buf), "\n");
@@ -1183,8 +1184,7 @@ void PS_Graphics::drawRGBImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDest)
 
 	// recall all that great info
 	g_snprintf(buf, sizeof(buf),"grestore\n");
-	m_ps->writeBytes(buf);
-	
+	m_ps->writeBytes(buf);	
 }
 
 void PS_Graphics::drawGrayImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDest)
@@ -1225,15 +1225,13 @@ void PS_Graphics::drawGrayImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDest
 			image->width, image->height * -1, image->height);
 	m_ps->writeBytes(buf);
 
-	g_snprintf(buf, sizeof(buf),"{currentfile\n  rowdata readhexstring pop}\nimage\n");
-	// color image does:
-	// sprintf(buf, "{currentfile\n  rowdata readhexstring pop}\nfalse 3\ncolorimage\n");
+	g_snprintf(buf, sizeof(buf),"{currentfile rowdata readhexstring pop}\nimage\n");
 	m_ps->writeBytes(buf);
 	
 	UT_Byte * start = image->data;
 	UT_Byte * cursor = NULL;
-	// 3 bytes per pixel in original RGB data
-	UT_Byte * end = start + image->width * image->height * 3;
+	// 1 byte per pixel in original gray data
+	UT_Byte * end = start + image->width * image->height;
 
 	UT_Byte hexbuf[3];
 	
@@ -1247,6 +1245,15 @@ void PS_Graphics::drawGrayImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDest
 		  throwing that (in hex) to the output file.
 		*/
 
+		/*
+		  libpng says that we should do this:
+
+		  int rw = red_weight * 65536;
+		  int gw = green_weight * 65536;
+		  int bw = 65536 - (rw + gw);
+		  gray = (rw*red + gw*green + bw*blue)/65536;
+		*/
+
 		// TODO : Balance these colors!  I don't like the output
 		// TODO : I get from a simple average or adding the YIQ
 		// TODO : weights.  Look at Netscape for something better.
@@ -1257,7 +1264,7 @@ void PS_Graphics::drawGrayImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDest
 										  static_cast<float>(3.0) )) );
 
 		m_ps->writeBytes(hexbuf, 2);
-		if (col == 38)
+		if (col == 40)
 		{
 			m_ps->writeByte(static_cast<UT_Byte>('\n'));
 			col = 0;
@@ -1354,31 +1361,3 @@ void PS_Graphics::_drawFT2Bitmap(UT_sint32 x, UT_sint32 y, FT_Bitmap * pBitmap)
 
 /***************************************************************************/
 /***************************************************************************/
-
-PS_GraphicsFactory::PS_GraphicsFactory(const UT_String & command)
-	: GR_GraphicsFactory(), m_command(command), m_mergeCount(0)
-{
-}
-
-PS_GraphicsFactory::~PS_GraphicsFactory()
-{
-}
-
-GR_Graphics* PS_GraphicsFactory::getGraphics()
-{
-	/* todo: keep a running count for print to file */
-	UT_String command;
-	if (m_command[0] == '|')
-		command = m_command;
-	else
-		command = UT_String_sprintf ("%s-%d", m_command.c_str(), m_mergeCount);
-	m_mergeCount++;
-
-	XAP_UnixApp * pApp = static_cast<XAP_UnixApp*>(XAP_App::getApp());
-	return new PS_Graphics ((command[0] == '|' ? command.c_str()+1 : command.c_str()), command.c_str(), 
-							pApp->getApplicationName(), pApp->getFontManager(),
-							(command[0] != '|'), pApp);
-}
-
-/***************************************************************************/
-/***************************************************************************/
