@@ -31,6 +31,7 @@
 #include "ut_timer.h"
 #include "xap_App.h"
 #include "xap_Frame.h"
+#include "xap_FrameImpl.h"
 #include "xap_Prefs.h"
 #include "xap_ViewListener.h"
 #include "ev_EditBinding.h"
@@ -54,29 +55,20 @@
 #include "xap_Toolbar_Layouts.h"
 #include "ut_sleep.h"
 
-/*****************************************************************/
-
-XAP_Frame::XAP_Frame(XAP_App * app)
-	: m_app(app),
+XAP_Frame::XAP_Frame(XAP_FrameImpl *pFrameImpl, XAP_App * pApp)
+	: m_pApp(pApp),
 	  m_pDoc(0),
 	  m_pView(0),
 	  m_pViewListener(0),
-	  m_lid((AV_ListenerId)-1),
+	  m_lid(static_cast<AV_ListenerId>(-1)),
 	  m_pScrollObj(0),
-	  m_szMenuLayoutName(0),
-	  m_szMenuLabelSetName(0),
-	  m_szToolbarLabelSetName(0),
-	  m_szToolbarAppearance(0),
 	  m_nView(0),
 	  m_iUntitled(0),
-	  m_pMouse(0),
-	  m_pKeyboard(0),
 	  m_pScrollbarViewListener(0),
-	  m_lidScrollbarViewListener((AV_ListenerId)-1),
-	  m_zoomType(z_100),
+	  m_lidScrollbarViewListener(static_cast<AV_ListenerId>(-1)),
+	  m_zoomType(z_PAGEWIDTH),
 	  m_pData(0),
 	  m_pInputModes(0),
-	  m_iFrameMode(XAP_NormalFrame),
 	  m_iIdAutoSaveTimer(0),
 	  m_iAutoSavePeriod(0),
 	  m_stAutoSaveExt(),
@@ -88,38 +80,32 @@ XAP_Frame::XAP_Frame(XAP_App * app)
 	  m_bisDragging(false),
 	  m_bHasDropped(false),
 	  m_bHasDroppedTB(false),
-	  m_ViewAutoUpdaterID(0),
-	  m_ViewAutoUpdater(NULL),
 	  m_bFirstDraw(false),
 	  m_bShowStatusbar(true),
-	  m_bShowMenubar(true)
+	  m_bShowMenubar(true),
+	  m_bIsFrameLocked(false),
+	  m_pFrameImpl(pFrameImpl),
+	  m_iZoomPercentage(100)
 {
-	m_app->rememberFrame(this);
-	memset(m_szTitle,0,sizeof(m_szTitle));
-	memset(m_szNonDecoratedTitle,0,sizeof(m_szNonDecoratedTitle));
+	m_pApp->rememberFrame(this);
+//	UT_DEBUGMSG(("Remembering UnCloned Frame \n"));
+//	UT_ASSERT(0);
 }
 
 XAP_Frame::XAP_Frame(XAP_Frame * f)
-	: m_app(f->m_app),                        // only clone a few things
+	: m_pApp(f->m_pApp),
 	m_pDoc(REFP(f->m_pDoc)),
 	m_pView(0),
 	m_pViewListener(0),
-	m_lid((AV_ListenerId)-1),
+	m_lid(static_cast<AV_ListenerId>(-1)),
 	m_pScrollObj(0),
-	m_szMenuLayoutName(0),
-	m_szMenuLabelSetName(0),
-	m_szToolbarLabelSetName(0),
-	m_szToolbarAppearance(0),
 	m_nView(0),
 	m_iUntitled(f->m_iUntitled),
-	m_pMouse(0),
-	m_pKeyboard(0),
 	m_pScrollbarViewListener(0),
-	m_lidScrollbarViewListener((AV_ListenerId)-1),
-	m_zoomType(z_100),
+	m_lidScrollbarViewListener(static_cast<AV_ListenerId>(-1)),
+	m_zoomType(f->m_zoomType),
 	m_pData(0),
 	m_pInputModes(0),
-	m_iFrameMode(XAP_NormalFrame),
 	m_iIdAutoSaveTimer(0),
 	m_bBackupRunning(false),
 	m_isrcId(0),
@@ -129,13 +115,14 @@ XAP_Frame::XAP_Frame(XAP_Frame * f)
 	m_bisDragging(false),
 	m_bHasDropped(false),
 	m_bHasDroppedTB(false),
-	m_ViewAutoUpdaterID(0),
-	m_ViewAutoUpdater(NULL),
-	m_bFirstDraw(false)
+	m_bFirstDraw(false),
+	m_bIsFrameLocked(false),
+	m_pFrameImpl(f->m_pFrameImpl->createInstance(this, f->m_pApp)),
+	m_iZoomPercentage(f->m_iZoomPercentage)
 {
-	m_app->rememberFrame(this, f);
-	memset(m_szTitle,0,sizeof(m_szTitle));
-	memset(m_szNonDecoratedTitle,0,sizeof(m_szNonDecoratedTitle));
+	m_pApp->rememberFrame(this, f);
+//	UT_DEBUGMSG(("Remembering Cloned Frame \n"));
+//	UT_ASSERT(0);
 }
 
 XAP_Frame::~XAP_Frame(void)
@@ -152,14 +139,17 @@ XAP_Frame::~XAP_Frame(void)
     }
 
 	// only delete the things that we created...
-  	DELETEP(m_pKeyboard);
-	DELETEP(m_pMouse);
+    // I do not like this; we should be deleting all our members,
+    // since they are no-one else's bussines (Tomas, Jan 30, 2003)
 
 	if (m_pView)
 		m_pView->removeListener(m_lid);
 
-	DELETEP(m_pView);
+
+	DELETEP(m_pFrameImpl);
+
 	DELETEP(m_pViewListener);
+	DELETEP(m_pView);
 
 	UNREFP(m_pDoc);
 
@@ -168,15 +158,6 @@ XAP_Frame::~XAP_Frame(void)
 
 	DELETEP(m_pScrollbarViewListener);
 
-	UT_VECTOR_FREEALL(char *,m_vecToolbarLayoutNames);
-	
-	FREEP(m_szMenuLayoutName);
-	FREEP(m_szMenuLabelSetName);
-	FREEP(m_szToolbarLabelSetName);
-	FREEP(m_szToolbarAppearance);
-
-	UT_VECTOR_PURGEALL(EV_Toolbar *, m_vecToolbars);
-
 	if (m_iIdAutoSaveTimer != 0)
 	{
 		UT_Timer *timer = UT_Timer::findTimer(m_iIdAutoSaveTimer);
@@ -191,11 +172,6 @@ XAP_Frame::~XAP_Frame(void)
 			UT_DEBUGMSG(("Timer [%d] not found\n", m_iIdAutoSaveTimer));
 		}
 	}
-	if(m_ViewAutoUpdaterID != 0)
-	{
-		m_ViewAutoUpdater->stop();
-	}
-	DELETEP(m_ViewAutoUpdater);
 }
 
 /*****************************************************************/
@@ -226,11 +202,11 @@ bool XAP_Frame::initialize(const char * szKeyBindingsKey, const char * szKeyBind
 	EV_EditBindingMap * pBindingMap = NULL;
 
 	if ((pApp->getPrefsValue(szKeyBindingsKey,
-				 (const XML_Char**)&szBindings)) && 
+				 static_cast<const XML_Char**>(&szBindings))) && 
 	    (szBindings) && (*szBindings))
-		pBindingMap = m_app->getBindingMap(szBindings);
+		pBindingMap = m_pApp->getBindingMap(szBindings);
 	if (!pBindingMap)
-		pBindingMap = m_app->getBindingMap(szKeyBindingsDefaultValue);
+		pBindingMap = m_pApp->getBindingMap(szKeyBindingsDefaultValue);
 	UT_ASSERT(pBindingMap);
 
 	if (!m_pInputModes)
@@ -251,12 +227,12 @@ bool XAP_Frame::initialize(const char * szKeyBindingsKey, const char * szKeyBind
 
 	const char * szMenuLayoutName = NULL;
 	if ((pApp->getPrefsValue(szMenuLayoutKey,
-				 (const XML_Char**)&szMenuLayoutName)) &&
+				 static_cast<const XML_Char**>(&szMenuLayoutName))) &&
 	    (szMenuLayoutName) && (*szMenuLayoutName))
 		;
 	else
 		szMenuLayoutName = szMenuLayoutDefaultValue;
-	UT_cloneString((char *&)m_szMenuLayoutName,szMenuLayoutName);
+	UT_cloneString((char *&)m_pFrameImpl->m_szMenuLayoutName,szMenuLayoutName);
 	
 	//////////////////////////////////////////////////////////////////
 	// select language for menu labels
@@ -264,12 +240,12 @@ bool XAP_Frame::initialize(const char * szKeyBindingsKey, const char * szKeyBind
 
 	const char * szMenuLabelSetName = NULL;
 	if ((pApp->getPrefsValue(szMenuLabelSetKey,
-				 (const XML_Char**)&szMenuLabelSetName)) &&
+				 static_cast<const XML_Char**>(&szMenuLabelSetName))) &&
 	    (szMenuLabelSetName) && (*szMenuLabelSetName))
 		;
 	else
 		szMenuLabelSetName = szMenuLabelSetDefaultValue;
-	UT_cloneString((char *&)m_szMenuLabelSetName,szMenuLabelSetName);
+	UT_cloneString((char *&)m_pFrameImpl->m_szMenuLabelSetName,szMenuLabelSetName);
 	
 	//////////////////////////////////////////////////////////////////
 	// select which toolbars we should display
@@ -277,7 +253,7 @@ bool XAP_Frame::initialize(const char * szKeyBindingsKey, const char * szKeyBind
 
 	const char * szToolbarLayouts = NULL;
 	if ((pApp->getPrefsValue(szToolbarLayoutsKey,
-							 (const XML_Char**)&szToolbarLayouts)) &&
+							 static_cast<const XML_Char**>(&szToolbarLayouts))) &&
 	    (szToolbarLayouts) && (*szToolbarLayouts))
 		;
 	else
@@ -293,7 +269,7 @@ bool XAP_Frame::initialize(const char * szKeyBindingsKey, const char * szKeyBind
 		{
 			char * szTempName;
 			UT_cloneString(szTempName,p);
-			m_vecToolbarLayoutNames.addItem(szTempName);
+			m_pFrameImpl->m_vecToolbarLayoutNames.addItem(szTempName);
 		}
 		free(szTemp);
 	}
@@ -308,12 +284,12 @@ bool XAP_Frame::initialize(const char * szKeyBindingsKey, const char * szKeyBind
 
 	const char * szToolbarLabelSetName = NULL;
 	if ((pApp->getPrefsValue(szToolbarLabelSetKey,
-				 (const XML_Char**)&szToolbarLabelSetName)) &&
+				 static_cast<const XML_Char**>(&szToolbarLabelSetName))) &&
 	    (szToolbarLabelSetName) && (*szToolbarLabelSetName))
 		;
 	else
 		szToolbarLabelSetName = szToolbarLabelSetDefaultValue;
-	UT_cloneString((char *&)m_szToolbarLabelSetName,szToolbarLabelSetName);
+	UT_cloneString((char *&)m_pFrameImpl->m_szToolbarLabelSetName,szToolbarLabelSetName);
 	
 	//////////////////////////////////////////////////////////////////
 	// select the appearance of the toolbar buttons
@@ -321,9 +297,9 @@ bool XAP_Frame::initialize(const char * szKeyBindingsKey, const char * szKeyBind
 
 	const char * szToolbarAppearance = NULL;
 	pApp->getPrefsValue(XAP_PREF_KEY_ToolbarAppearance,
-			    (const XML_Char**)&szToolbarAppearance);
+			    static_cast<const XML_Char**>(&szToolbarAppearance));
 	UT_ASSERT((szToolbarAppearance) && (*szToolbarAppearance));
-	UT_cloneString((char *&)m_szToolbarAppearance,szToolbarAppearance);
+	UT_cloneString((char *&)m_pFrameImpl->m_szToolbarAppearance,szToolbarAppearance);
 
 	//////////////////////////////////////////////////////////////////
 	// select the auto save options
@@ -341,28 +317,84 @@ bool XAP_Frame::initialize(const char * szKeyBindingsKey, const char * szKeyBind
 	// select the default zoom settings
 	//////////////////////////////////////////////////////////////////
 	pApp->getPrefsValue(XAP_PREF_KEY_ZoomType, stTmp);
+	UT_DEBUGMSG(("Zoom type from prefs is %s \n",stTmp.c_str()));
+	UT_uint32 iZoom = 100;
 	if( UT_stricmp( stTmp.c_str(), "100" ) == 0 )
 	{
 		m_zoomType = z_100;
+		iZoom = 100;
+	}
+	else if( UT_stricmp( stTmp.c_str(), "75" ) == 0 )
+	{
+		m_zoomType = z_75;
+		iZoom = 75;
+	}
+	else if( UT_stricmp( stTmp.c_str(), "200" ) == 0 )
+	{
+		m_zoomType = z_200;
+		iZoom = 200;
 	}
 	else if( UT_stricmp( stTmp.c_str(), "Width" ) == 0 )
 	{
 		m_zoomType = z_PAGEWIDTH;
+		const XML_Char * szZoom = NULL;
+		m_pApp->getPrefsValue(XAP_PREF_KEY_ZoomPercentage,
+							  static_cast<const XML_Char**>(&szZoom));
+		if(szZoom)
+		{
+			iZoom = atoi(szZoom);
+			if(iZoom < XAP_DLG_ZOOM_MINIMUM_ZOOM) 
+				iZoom = 100;
+			else if (iZoom > XAP_DLG_ZOOM_MAXIMUM_ZOOM) 
+				iZoom = 100;
+		}
+		else
+		{
+			iZoom = 100;
+		}
 	}
 	else if( UT_stricmp( stTmp.c_str(), "Page" ) == 0 )
 	{
 		m_zoomType = z_WHOLEPAGE;
+		const XML_Char * szZoom = NULL;
+		m_pApp->getPrefsValue(XAP_PREF_KEY_ZoomPercentage,
+							  static_cast<const XML_Char**>(&szZoom));
+		if(szZoom)
+		{
+			iZoom = atoi(szZoom);
+			if(iZoom < XAP_DLG_ZOOM_MINIMUM_ZOOM) 
+				iZoom = 100;
+			else if (iZoom > XAP_DLG_ZOOM_MAXIMUM_ZOOM) 
+				iZoom = 100;
+		}
+		else
+		{
+			iZoom = 100;
+		}
 	}
 	else
 	{
-		m_zoomType = z_100;
+		iZoom = atoi( stTmp.c_str() );
+
+		// These limits are defined in xap_Dlg_Zoom.h
+		if ((iZoom <= XAP_DLG_ZOOM_MAXIMUM_ZOOM) && (iZoom >= XAP_DLG_ZOOM_MINIMUM_ZOOM)) 
+		{
+			m_zoomType = z_PERCENT;
+			XAP_Frame::setZoomPercentage( iZoom );
+		}
+		else
+		  m_zoomType = z_100;
 	}
+	XAP_Frame::setZoomPercentage( iZoom );
 
 	
 	//////////////////////////////////////////////////////////////////
 	// ... add other stuff here ...
 	//////////////////////////////////////////////////////////////////
 
+	// initialize our helper
+	m_pFrameImpl->_initialize();
+
 	return true;
 }
 
@@ -371,7 +403,11 @@ static void autoSaveCallback(UT_Worker *wkr)
 {
 	UT_DEBUGMSG(("Autosaving doc...\n"));
 	XAP_Frame *me = static_cast<XAP_Frame *> (wkr->getInstanceData());
-
+	AD_Document * pDoc = me->getCurrentDoc();
+	if(pDoc && pDoc->isPieceTableChanging())
+	{
+		UT_DEBUGMSG(("PieceTable is changing no backup made \n"));
+	}
 	if (me->isDirty())
 	{
 		UT_Error error = me->backup();
@@ -393,8 +429,8 @@ void XAP_Frame::_createAutoSaveTimer()
 	UT_Timer *timer = UT_Timer::static_constructor(autoSaveCallback, this);
 	UT_String stPeriod;
 	
-	UT_ASSERT(m_app);
-	m_app->getPrefsValue(XAP_PREF_KEY_AutoSaveFilePeriod, stPeriod);
+	UT_ASSERT(m_pApp);
+	m_pApp->getPrefsValue(XAP_PREF_KEY_AutoSaveFilePeriod, stPeriod);
 	UT_ASSERT(stPeriod.empty() == false);
 	m_iAutoSavePeriod = atoi(stPeriod.c_str());
 	
@@ -407,7 +443,7 @@ void XAP_Frame::_createAutoSaveTimer()
 /*!
  * This starts the auto Updater for the view
  */
-void XAP_Frame::_startViewAutoUpdater(void)
+void XAP_FrameImpl::_startViewAutoUpdater(void)
 {
 	if(m_ViewAutoUpdaterID == 0)
 	{
@@ -415,7 +451,7 @@ void XAP_Frame::_startViewAutoUpdater(void)
 		m_ViewAutoUpdater->set(500);
 		m_ViewAutoUpdaterID = m_ViewAutoUpdater->getIdentifier();
 		m_ViewAutoUpdater->start();
-		m_bFirstDraw = false;
+		m_pFrame->m_bFirstDraw = false;
 	}
 }
 
@@ -423,54 +459,56 @@ void XAP_Frame::_startViewAutoUpdater(void)
  * This static function updates the current view in frame while the layout
  * is filling.
  */
-void /* static*/ XAP_Frame::viewAutoUpdater(UT_Worker *wkr)
+void /* static*/ XAP_FrameImpl::viewAutoUpdater(UT_Worker *wkr)
 {
-	XAP_Frame *pFrame = static_cast<XAP_Frame *> (wkr->getInstanceData());
-	const XAP_StringSet * pSS = pFrame->getApp()->getStringSet();
-	UT_String msg = pSS->getValue(XAP_STRING_ID_MSG_BuildingDoc);
-	pFrame->setCursor(GR_Graphics::GR_CURSOR_WAIT);
-	AV_View * pView = pFrame->getCurrentView();
+	XAP_FrameImpl *pFrameImpl = static_cast<XAP_FrameImpl *> (wkr->getInstanceData());
+	XAP_App *pApp = pFrameImpl->m_pFrame->getApp(); // WL_REFACTOR: may be redundant
+	const XAP_StringSet * pSS = pFrameImpl->m_pFrame->getApp()->getStringSet();
+	UT_String msg = pSS->getValue(XAP_STRING_ID_MSG_BuildingDoc, pApp->getDefaultEncoding());
+	pFrameImpl->_setCursor(GR_Graphics::GR_CURSOR_WAIT);
+	AV_View * pView = pFrameImpl->m_pFrame->getCurrentView();
 	UT_DEBUGMSG(("SEVIOR: frame view updater \n"));
 	if(!pView)
 	{
-		pFrame->setCursor(GR_Graphics::GR_CURSOR_DEFAULT);
-		pFrame->m_ViewAutoUpdater->stop();
-		pFrame->m_ViewAutoUpdaterID = 0;
-		DELETEP(pFrame->m_ViewAutoUpdater);
+		pFrameImpl->m_pFrame->setCursor(GR_Graphics::GR_CURSOR_DEFAULT);
+		pFrameImpl->m_ViewAutoUpdater->stop();
+		pFrameImpl->m_ViewAutoUpdaterID = 0;
+		DELETEP(pFrameImpl->m_ViewAutoUpdater);
 		return;
 	}
 	if(!pView->isLayoutFilling() && (pView->getPoint() > 0))
 	{
 		GR_Graphics * pG = pView->getGraphics();
 		pG->setCursor(GR_Graphics::GR_CURSOR_DEFAULT);
-		pFrame->setCursor(GR_Graphics::GR_CURSOR_DEFAULT);
+		pFrameImpl->m_pFrame->setCursor(GR_Graphics::GR_CURSOR_DEFAULT);
 		pView->setCursorToContext();
-		pFrame->m_ViewAutoUpdater->stop();
-		pFrame->m_ViewAutoUpdaterID = 0;
-		DELETEP(pFrame->m_ViewAutoUpdater);
+		pFrameImpl->m_ViewAutoUpdater->stop();
+		pFrameImpl->m_ViewAutoUpdaterID = 0;
+		DELETEP(pFrameImpl->m_ViewAutoUpdater);
 		pView->draw();
+
 		return;
 	}
-	if(!pView->isLayoutFilling() && !pFrame->m_bFirstDraw)
+	if(!pView->isLayoutFilling() && !pFrameImpl->m_pFrame->m_bFirstDraw)
 	{
 		GR_Graphics * pG = pView->getGraphics();
 		pG->setCursor(GR_Graphics::GR_CURSOR_WAIT);
-		pFrame->setCursor(GR_Graphics::GR_CURSOR_WAIT);
-		pFrame->setStatusMessage ( (XML_Char *) msg.c_str());
+		pFrameImpl->_setCursor(GR_Graphics::GR_CURSOR_WAIT);
+		pFrameImpl->m_pFrame->setStatusMessage ( static_cast<const XML_Char *>(msg.c_str()) );
 		return;
 	}
 	GR_Graphics * pG = pView->getGraphics();
 	pG->setCursor(GR_Graphics::GR_CURSOR_WAIT);
-	pFrame->setCursor(GR_Graphics::GR_CURSOR_WAIT);
-	pFrame->setStatusMessage ( (XML_Char *) msg.c_str());
+	pFrameImpl->_setCursor(GR_Graphics::GR_CURSOR_WAIT);
+	pFrameImpl->m_pFrame->setStatusMessage ( static_cast<const XML_Char *>(msg.c_str()) );
 
 	if(pView->getPoint() > 0)
 	{
 		pView->updateLayout();
-		if(!pFrame->m_bFirstDraw)
+		if(!pFrameImpl->m_pFrame->m_bFirstDraw)
 		{
 			pView->draw();
-			pFrame->m_bFirstDraw = true;
+			pFrameImpl->m_pFrame->m_bFirstDraw = true;
 		}
 		else
 		{
@@ -479,6 +517,16 @@ void /* static*/ XAP_Frame::viewAutoUpdater(UT_Worker *wkr)
 	}
 }
 
+UT_RGBColor XAP_Frame::getColorSelBackground () const
+{
+  return m_pFrameImpl->getColorSelBackground ();
+}
+
+UT_RGBColor XAP_Frame::getColorSelForeground () const
+{
+  return m_pFrameImpl->getColorSelForeground ();
+}
+
 EV_EditEventMapper * XAP_Frame::getEditEventMapper(void) const
 {
 	UT_ASSERT(m_pInputModes);
@@ -497,7 +545,7 @@ UT_sint32 XAP_Frame::setInputMode(const char * szName)
 	{
 		// map not previously loaded -- we need to install it first
 
-		EV_EditBindingMap * pBindingMap = m_app->getBindingMap(szName);
+		EV_EditBindingMap * pBindingMap = m_pApp->getBindingMap(szName);
 		UT_ASSERT(pBindingMap);
 		bool bResult;
 		bResult = m_pInputModes->createInputMode(szName,pBindingMap);
@@ -522,7 +570,7 @@ const char * XAP_Frame::getInputMode(void) const
 
 XAP_App * XAP_Frame::getApp(void) const
 {
-	return m_app;
+	return m_pApp;
 }
 
 AV_View * XAP_Frame::getCurrentView(void) const
@@ -579,121 +627,72 @@ const char * XAP_Frame::getViewKey(void) const
 	// Why "+3"?  For the "0x" and the null. 
 	static char buf[(sizeof(void *) * 2) + 3];
 
-	sprintf(buf, "%p", (void *)m_pDoc);
+	sprintf(buf, "%p", static_cast<void *>(m_pDoc));
 
 	return buf;
 }
 
 const char * XAP_Frame::getTitle(int len) const
 {
+	UT_ASSERT(len >= 0);
+
 	// Returns the pathname being edited (with view and dirty bit
 	// '*' adornments), if all that fits. If it doesn't fit,
 	// returns the tail of the string that does fit. Would be
 	// better to chop it at a pathname separator boundary.
-	if ((int)strlen(m_szTitle) <= len)
+	if (static_cast<int>(m_sTitle.size()) <= len)
+		return m_sTitle.utf8_str();
+
+	// WL_FIXME: we probably need a string truncation function, in the ut_utf8string class..
+	UT_UTF8Stringbuf::UTF8Iterator iter = m_sTitle.getIterator ();
+	iter = iter.start ();
+	for (int currentSize = m_sTitle.size(); currentSize > len; currentSize--)
+		iter.advance();
+	return iter.current();
+}
+
+const char * XAP_Frame::getNonDecoratedTitle() const
+{
+	return m_sNonDecoratedTitle.utf8_str();
+}
+
+void XAP_Frame::setZoomPercentage(UT_uint32 iZoom)
+{
+	m_iZoomPercentage = iZoom;
+	XAP_App * pApp = getApp();
+	UT_ASSERT(pApp);
+	XAP_Prefs * pPrefs = pApp->getPrefs();
+	UT_ASSERT(pPrefs);
+	XAP_PrefsScheme * pScheme = pPrefs->getCurrentScheme(true);
+	UT_ASSERT(pScheme);
+	UT_String sZoom;
+	UT_String_sprintf(sZoom,"%d",iZoom);
+	if(getZoomType() == z_PAGEWIDTH)
 	{
-		return m_szTitle;
+		pScheme->setValue(XAP_PREF_KEY_ZoomType,"Width");
+	}
+	else if(getZoomType() == z_WHOLEPAGE)
+	{
+		pScheme->setValue(XAP_PREF_KEY_ZoomType,"Page");
 	}
 	else
 	{
-		return m_szTitle + (strlen(m_szTitle)-len);
+		pScheme->setValue(XAP_PREF_KEY_ZoomType,sZoom.c_str());
 	}
-}
-
-const char * XAP_Frame::getTempNameFromTitle(void) const
-{
-	// extract a filename or pathname from the title.
-	// strip off all of the title's window decorations (the ":1 *").
-
-	return m_szNonDecoratedTitle;
-}
-	
-bool XAP_Frame::updateTitle()
-{
-	/*
-		The document title for this window has changed, so we need to:
-
-		1. Update m_szTitle accordingly.	(happens here)
-		2. Update the window title.			(happens in subclass)
-
-		Note that we don't need to update the contents of the Window menu, 
-		because that happens dynamically at menu pop-up time.  
-	*/
-
-	const char* szName = m_pDoc->getFilename();
-
-	if (szName && *szName)
-	{
-		// Note: The previous version of this code blew up
-		// when assertions were turned on and more than 244
-		// characters were to be copied. I now copy only
-		// the last 244 characters in that case. I do not know
-		// where "244" comes from - the buffer being copied into
-		// is currently 512 bytes. However, even 244 characters
-		// is way too long for a title bar, so no reason to
-		// increase the size to fit more snugly into the buffer.
-		// Here's that previous assertion:
-		// UT_ASSERT(strlen(szName) < 245); // TODO need #define for this number
-
-		// Check that the buffer (with generous room for
-		// later decorations) is big enough.
-		UT_ASSERT(sizeof(m_szTitle) > 245 + 30); 
-
-		if (strlen(szName) <= 244)
-		{
-			strcpy(m_szTitle, szName); 
-		}
-		else 
-		{
-			// copy the tail of the pathname, the useful part.
-			// would be a bit more useful to break it at a	
-			// pathname component separator.
-			strcpy(m_szTitle, szName + (strlen(szName) - 244));
-		}
-	}
-	else
-	{
-		UT_ASSERT(m_iUntitled);
-		const XAP_StringSet * pSS = m_app->getStringSet();
-		
-		sprintf(m_szTitle, pSS->getValue(XAP_STRING_ID_UntitledDocument), m_iUntitled);
-	}
-
-	strcpy(m_szNonDecoratedTitle, m_szTitle);
-	
-	if (m_nView)
-	{
-		// multiple top-level views, so append : & view number
-		char buf[6];
-		UT_ASSERT(m_nView < 10000);
-		sprintf(buf, ":%d", m_nView);
-		strcat(m_szTitle, buf);
-	}
-
-	if (m_pDoc->isDirty())
-	{
-		// append " *"
-		strcat(m_szTitle, " *");
-	}
-
-	return true;
-}
-
-void XAP_Frame::setZoomPercentage(UT_uint32 /* iZoom */)
-{
-	// default does nothing.  see subclasses for override
+	UT_DEBUGMSG(("zoom is set to %s \n",sZoom.c_str()));
+	pScheme->setValue(XAP_PREF_KEY_ZoomPercentage,sZoom.c_str());
 }
 
 UT_uint32 XAP_Frame::getZoomPercentage(void)
 {
-	return 100;	// default implementation
+	return m_iZoomPercentage;
 }
 
 EV_Toolbar *  XAP_Frame::getToolbar(UT_uint32 ibar)
 {
-	if(ibar >= m_vecToolbars.getItemCount())
+	if(ibar >= m_pFrameImpl->m_vecToolbars.getItemCount())
 		return NULL;
-	return (EV_Toolbar *) m_vecToolbars.getNthItem(ibar);
+	return static_cast<EV_Toolbar *>(m_pFrameImpl->m_vecToolbars.getNthItem(ibar));
 }
 
 bool XAP_Frame::repopulateCombos(void)
@@ -713,16 +712,15 @@ bool XAP_Frame::repopulateCombos(void)
 	return true;
 }
 
-void XAP_Frame::_createToolbars(void)
+void XAP_FrameImpl::_createToolbars(void)
 {
 	bool bResult;
 	UT_uint32 nrToolbars = m_vecToolbarLayoutNames.getItemCount();
 	for (UT_uint32 k=0; k < nrToolbars; k++)
 	{
-		EV_Toolbar * pToolbar
-				= _newToolbar(m_app, this,
-					(const char *)m_vecToolbarLayoutNames.getNthItem(k),
-					(const char *)m_szToolbarLabelSetName);
+		EV_Toolbar * pToolbar = m_pFrame->_newToolbar(m_pFrame->m_pApp, m_pFrame,
+							      reinterpret_cast<const char *>(m_vecToolbarLayoutNames.getNthItem(k)),
+							      reinterpret_cast<const char *>(m_szToolbarLabelSetName));
 		UT_ASSERT(pToolbar);
 		bResult = pToolbar->synthesize();
 		UT_ASSERT(bResult);
@@ -735,7 +733,7 @@ UT_sint32 XAP_Frame::findToolbarNr(EV_Toolbar * pTB)
 {
 	UT_uint32 i = 0;
 	bool bFound =  false;
-	for(i =0; !bFound && (i < m_vecToolbars.getItemCount()); i++)
+	for(i =0; !bFound && (i < m_pFrameImpl->m_vecToolbars.getItemCount()); i++)
 	{
 		EV_Toolbar * pTmp = getToolbar(i);
 		if(pTmp == pTB)
@@ -746,22 +744,11 @@ UT_sint32 XAP_Frame::findToolbarNr(EV_Toolbar * pTB)
 	}
 	if(bFound)
 	{
-		return (UT_sint32) i;
+		return static_cast<UT_sint32>(i);
 	}
 	return -1;
 }
 
-
-EV_Mouse * XAP_Frame::getMouse(void)
-{
-	return m_pMouse;
-}
-
-EV_Keyboard * XAP_Frame::getKeyboard(void)
-{
-	return m_pKeyboard;
-}
-
 void XAP_Frame::setAutoSaveFile(bool b)
 {
 	if (b && !m_iIdAutoSaveTimer)
@@ -801,88 +788,86 @@ void XAP_Frame::setAutoSaveFileExt(const UT_String &stExt)
 	m_stAutoSaveExt = stExt;
 }
 
-XAP_Dialog_MessageBox::tAnswer XAP_Frame::showMessageBox(const char *szMessage,
-											  XAP_Dialog_MessageBox::tButtons buttons,
-											  XAP_Dialog_MessageBox::tAnswer default_answer)
+XAP_Dialog_MessageBox * XAP_Frame::createMessageBox(XAP_String_Id id,
+						    XAP_Dialog_MessageBox::tButtons buttons,
+						    XAP_Dialog_MessageBox::tAnswer default_answer,
+						    ...)
+{
+  	XAP_DialogFactory * pDialogFactory
+		= static_cast<XAP_DialogFactory *>(getDialogFactory());
+
+	XAP_Dialog_MessageBox * pDialog
+		= static_cast<XAP_Dialog_MessageBox *>(pDialogFactory->requestDialog(XAP_DIALOG_ID_MESSAGE_BOX));
+	UT_ASSERT(pDialog);
+
+	if (id > 0) {
+		char * szNewMessage = static_cast<char *>(malloc(sizeof(char) * 256));
+		const XAP_StringSet * pSS = getApp()->getStringSet();
+		
+		va_list args;		
+		va_start(args, default_answer);		
+		vsprintf(szNewMessage, static_cast<const char*>(pSS->getValue(id, m_pApp->getDefaultEncoding()).c_str()), args);
+		va_end(args);
+
+		pDialog->setMessage(szNewMessage);
+		
+		// XAP_MessageBox makes a copy of the message, so free it
+		FREEP(szNewMessage);
+	}
+	pDialog->setButtons(buttons);
+	pDialog->setDefaultAnswer(default_answer);
+	
+	return pDialog;
+}
+XAP_Dialog_MessageBox::tAnswer XAP_Frame::showMessageBox(XAP_Dialog_MessageBox * pDialog)
 {
 	raise();
 
-	XAP_DialogFactory * pDialogFactory
-		= (XAP_DialogFactory *)(getDialogFactory());
-
-	XAP_Dialog_MessageBox * pDialog
-		= (XAP_Dialog_MessageBox *)(pDialogFactory->requestDialog(XAP_DIALOG_ID_MESSAGE_BOX));
-	UT_ASSERT(pDialog);
-
-	pDialog->setMessage(szMessage);
-
-	pDialog->setButtons(buttons);
-	pDialog->setDefaultAnswer(default_answer);
-
 	pDialog->runModal(this);
-
 	XAP_Dialog_MessageBox::tAnswer ans = pDialog->getAnswer();
-
-	pDialogFactory->releaseDialog(pDialog);
+	delete pDialog;
 
 	return ans;
 }
 
+XAP_Dialog_MessageBox::tAnswer XAP_Frame::showMessageBox(XAP_String_Id id,
+							 XAP_Dialog_MessageBox::tButtons buttons,
+							 XAP_Dialog_MessageBox::tAnswer default_answer)
+{
+  XAP_Dialog_MessageBox * pDialog = createMessageBox(id, buttons, default_answer);
+  return showMessageBox(pDialog);
+}
 
 XAP_Dialog_MessageBox::tAnswer XAP_Frame::showMessageBox(XAP_String_Id id,
-											  XAP_Dialog_MessageBox::tButtons buttons,
-											  XAP_Dialog_MessageBox::tAnswer default_answer,
-											  const char *p_str1)
+							 XAP_Dialog_MessageBox::tButtons buttons,
+							 XAP_Dialog_MessageBox::tAnswer default_answer,
+							 const char * sz)
 {
-	raise();
+  XAP_Dialog_MessageBox * pDialog = createMessageBox(id, buttons, default_answer, sz);
+  return showMessageBox(pDialog);
+}
 
-	XAP_DialogFactory * pDialogFactory
-		= (XAP_DialogFactory *)(getDialogFactory());
-
-	XAP_Dialog_MessageBox * pDialog
-		= (XAP_Dialog_MessageBox *)(pDialogFactory->requestDialog(XAP_DIALOG_ID_MESSAGE_BOX));
-	UT_ASSERT(pDialog);
-
-	const XAP_StringSet * pSS = getApp()->getStringSet();
-
-	if(p_str1)
-	{
-		pDialog->setMessage((char*)pSS->getValue(id), p_str1);
-	}
-	else
-	{
-		pDialog->setMessage((char*)pSS->getValue(id));
-	}
-
-
-	pDialog->setButtons(buttons);
-	pDialog->setDefaultAnswer(default_answer);
-
-	pDialog->runModal(this);
-
-	XAP_Dialog_MessageBox::tAnswer ans = pDialog->getAnswer();
-
-	pDialogFactory->releaseDialog(pDialog);
-
-	return ans;
+XAP_Dialog_MessageBox::tAnswer XAP_Frame::showMessageBox(const char * szMessage,
+							 XAP_Dialog_MessageBox::tButtons buttons,
+							 XAP_Dialog_MessageBox::tAnswer default_answer)
+{
+  XAP_Dialog_MessageBox * pDialog = createMessageBox(0, buttons, default_answer);
+  pDialog->setMessage(szMessage);
+  return showMessageBox(pDialog);
 }
 
 UT_String XAP_Frame::makeBackupName(const char* szExt)
 {
-  UT_String ext(szExt ? szExt : m_stAutoSaveExt);
+  UT_String ext(szExt ? szExt : m_stAutoSaveExt.c_str());
   UT_String oldName(m_pDoc->getFilename() ? m_pDoc->getFilename() : "");
   UT_String backupName;
   
   if (oldName.empty())
     {
-      const XAP_StringSet * pSS = m_app->getStringSet();
-      const char *szTmp = pSS->getValue(XAP_STRING_ID_UntitledDocument);
-      int iLen = strlen(szTmp) + 10;
-      char *szTmp2 = new char[iLen];
-      
-      sprintf(szTmp2, szTmp, m_iUntitled);
-      oldName = szTmp2;
-      delete[] (szTmp2);
+      const XAP_StringSet * pSS = m_pApp->getStringSet();
+	  const UT_String sTmp = pSS->getValue(XAP_STRING_ID_UntitledDocument, m_pApp->getDefaultEncoding());
+	  UT_String_sprintf(oldName, sTmp.c_str(), m_iUntitled);
+
       UT_DEBUGMSG(("Untitled.  We will give it the name [%s]\n", oldName.c_str()));
     }
   else
@@ -904,6 +889,13 @@ UT_Error XAP_Frame::backup(const char* szExt)
 {
 	if (m_bBackupRunning)
 		return UT_OK;
+
+	if (!m_pDoc)
+	{
+		UT_DEBUGMSG(("File NOT saved! doc is NULL.\n"));
+		return UT_OK;
+	}
+
 	m_bBackupRunning = true;
 
 	UT_String backupName = makeBackupName ( szExt );
@@ -925,12 +917,14 @@ void XAP_Frame::updateZoom(void)
 		newZoom = m_pView->calculateZoomPercentForPageWidth();
 		if      (newZoom < XAP_DLG_ZOOM_MINIMUM_ZOOM) newZoom = XAP_DLG_ZOOM_MINIMUM_ZOOM;
 		else if (newZoom > XAP_DLG_ZOOM_MAXIMUM_ZOOM) newZoom = XAP_DLG_ZOOM_MAXIMUM_ZOOM;
+		XAP_Frame::setZoomPercentage( newZoom );
 		setZoomPercentage( newZoom );
 		break;
 	case z_WHOLEPAGE:
 		newZoom = m_pView->calculateZoomPercentForWholePage() ;
 		if      (newZoom < XAP_DLG_ZOOM_MINIMUM_ZOOM) newZoom = XAP_DLG_ZOOM_MINIMUM_ZOOM;
 		else if (newZoom > XAP_DLG_ZOOM_MAXIMUM_ZOOM) newZoom = XAP_DLG_ZOOM_MAXIMUM_ZOOM;
+		XAP_Frame::setZoomPercentage( newZoom );
 		setZoomPercentage( newZoom );
 		break;
 	default:
@@ -938,27 +932,17 @@ void XAP_Frame::updateZoom(void)
    }
 }
 
-
-/*!
- * This method destroys toolbar number ibar, then rebuilds it and displays
- * as requested from the current toolbar layouts. Used for dynamic toolbars.
- * This virtual method is overidden by the platform classes.
- */ 
-void XAP_Frame::rebuildToolbar(UT_uint32 ibar)
-{
-}
-
 /*!
  * This method rebuilds all the toolbars in the frame. Useful for when the
  * user wants to revert to default toolbars.
  */
 void XAP_Frame::rebuildAllToolbars(void)
 {
-	UT_uint32 count = m_vecToolbars.getItemCount();
+	UT_uint32 count = m_pFrameImpl->m_vecToolbars.getItemCount();
 	UT_uint32 i =0;
 	for(i=0; i< count; i++)
 	{
-		rebuildToolbar(i);
+		m_pFrameImpl->_rebuildToolbar(i);
 	}
 }
 
@@ -1020,15 +1004,16 @@ void XAP_Frame::dragEnd(XAP_Toolbar_Id srcId)
 	{
 		if(m_isrcId != m_idestId)
 		{
-			const char * szTBSrcName = (const char *) m_vecToolbarLayoutNames.getNthItem(m_isrcTBNr);
+			const char * szTBSrcName = reinterpret_cast<const char *>(m_pFrameImpl->m_vecToolbarLayoutNames.getNthItem(m_isrcTBNr));
 			getApp()->getToolbarFactory()->removeIcon(szTBSrcName,m_isrcId);
-			const char * szTBDestName = (const char *) m_vecToolbarLayoutNames.getNthItem(m_idestTBNr);
+			const char * szTBDestName = reinterpret_cast<const char *>(m_pFrameImpl->m_vecToolbarLayoutNames.getNthItem(m_idestTBNr));
 			getApp()->getToolbarFactory()->addIconBefore(szTBDestName,m_isrcId,m_idestId);
-			rebuildToolbar(m_isrcTBNr);
+			m_pFrameImpl->_rebuildToolbar(m_isrcTBNr);
 			if(m_isrcTBNr != m_idestTBNr)
 			{
-				rebuildToolbar(m_idestTBNr);
+				m_pFrameImpl->_rebuildToolbar(m_idestTBNr);
 			}
+		getApp()->setToolbarsCustomized(true);
 		}
 	}
 //
@@ -1036,15 +1021,14 @@ void XAP_Frame::dragEnd(XAP_Toolbar_Id srcId)
 //
 	if(m_bisDragging && m_bHasDroppedTB)
 	{
-		const char * szTBSrcName = (const char *) m_vecToolbarLayoutNames.getNthItem(m_isrcTBNr);
+		const char * szTBSrcName = reinterpret_cast<const char *>(m_pFrameImpl->m_vecToolbarLayoutNames.getNthItem(m_isrcTBNr));
 		getApp()->getToolbarFactory()->removeIcon(szTBSrcName,m_isrcId);
-		const char * szTBDestName = (const char *) m_vecToolbarLayoutNames.getNthItem(m_idestTBNr);
-		const EV_Toolbar_Layout * pTBDest = getToolbar(m_idestTBNr)->getToolbarLayout();
+		const char * szTBDestName = reinterpret_cast<const char *>(m_pFrameImpl->m_vecToolbarLayoutNames.getNthItem(m_idestTBNr));
 		getApp()->getToolbarFactory()->addIconAtEnd(szTBDestName,m_isrcId);
-		rebuildToolbar(m_isrcTBNr);
+		m_pFrameImpl->_rebuildToolbar(m_isrcTBNr);
 		if(m_isrcTBNr != m_idestTBNr)
 		{
-			rebuildToolbar(m_idestTBNr);
+			m_pFrameImpl->_rebuildToolbar(m_idestTBNr);
 		}
 	}
 //
@@ -1057,9 +1041,9 @@ void XAP_Frame::dragEnd(XAP_Toolbar_Id srcId)
 //
 		if(XAP_Dialog_MessageBox::a_YES == showMessageBox(XAP_STRING_ID_DLG_Remove_Icon,XAP_Dialog_MessageBox::b_YN,XAP_Dialog_MessageBox::a_NO))
 		{
-			const char * szTBSrcName = (const char *) m_vecToolbarLayoutNames.getNthItem(m_isrcTBNr);
+			const char * szTBSrcName = reinterpret_cast<const char *>(m_pFrameImpl->m_vecToolbarLayoutNames.getNthItem(m_isrcTBNr));
 			getApp()->getToolbarFactory()->removeIcon(szTBSrcName,m_isrcId);
-			rebuildToolbar(m_isrcTBNr);
+			m_pFrameImpl->_rebuildToolbar(m_isrcTBNr);
 		}
 	}
 	m_isrcId = 0;
@@ -1071,6 +1055,20 @@ void XAP_Frame::dragEnd(XAP_Toolbar_Id srcId)
 	m_bHasDroppedTB = false;
 }
 
+UT_uint32 XAP_Frame::getTimeSinceSave() const
+{
+	return m_pDoc->getTimeSinceSave();
+}
+
+XAP_FrameMode XAP_Frame::getFrameMode()
+{
+	return m_pFrameImpl->m_iFrameMode;
+}
+void XAP_Frame::setFrameMode(XAP_FrameMode iFrameMode)
+{
+	m_pFrameImpl->m_iFrameMode = iFrameMode;
+}
+
 //////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////
 
@@ -1117,7 +1115,7 @@ bool XAP_InputModes::setCurrentMap(const char * szName)
 	UT_uint32 k;
 
 	for (k=0; k<kLimit; k++)
-		if (UT_stricmp(szName,(const char *)m_vecNames.getNthItem(k)) == 0)
+		if (UT_stricmp(szName,reinterpret_cast<const char *>(m_vecNames.getNthItem(k))) == 0)
 		{
 			m_indexCurrentEventMap = k;
 			return true;
@@ -1128,12 +1126,12 @@ bool XAP_InputModes::setCurrentMap(const char * szName)
 
 EV_EditEventMapper * XAP_InputModes::getCurrentMap(void) const
 {
-	return (EV_EditEventMapper *)m_vecEventMaps.getNthItem(m_indexCurrentEventMap);
+	return static_cast<EV_EditEventMapper *>(m_vecEventMaps.getNthItem(m_indexCurrentEventMap));
 }
 
 const char * XAP_InputModes::getCurrentMapName(void) const
 {
-	return (const char *)m_vecNames.getNthItem(m_indexCurrentEventMap);
+	return reinterpret_cast<const char *>(m_vecNames.getNthItem(m_indexCurrentEventMap));
 }
 
 EV_EditEventMapper * XAP_InputModes::getMapByName(const char * szName) const
@@ -1142,8 +1140,8 @@ EV_EditEventMapper * XAP_InputModes::getMapByName(const char * szName) const
 	UT_uint32 k;
 
 	for (k=0; k<kLimit; k++)
-		if (UT_stricmp(szName,(const char *)m_vecNames.getNthItem(k)) == 0)
-			return (EV_EditEventMapper *)m_vecEventMaps.getNthItem(k);
+		if (UT_stricmp(szName,reinterpret_cast<const char *>(m_vecNames.getNthItem(k))) == 0)
+			return static_cast<EV_EditEventMapper *>(m_vecEventMaps.getNthItem(k));
 
 	return NULL;
 }
