@@ -274,6 +274,10 @@ bool fp_Line::isLastLineInBlock(void) const
 
 void fp_Line::setMaxWidth(UT_sint32 iMaxWidth)
 {
+	if(iMaxWidth < 60) // This is hardwired to disallow -ve or too small values
+	{
+		iMaxWidth = 60;
+	}
 	m_iMaxWidth = iMaxWidth;
 }
 
@@ -2841,6 +2845,12 @@ UT_uint32 fp_Line::countJustificationPoints(void)
 		{
 			iSpaceCount++;
 		}
+		else if (   pRun->getType () == FPRUN_DIRECTIONMARKER || pRun->getType () == FPRUN_FMTMARK
+				 || pRun->getType () == FPRUN_BOOKMARK || pRun->getType () == FPRUN_HYPERLINK)
+		{
+			// these runs do not expand under justification, but neither do they contain non-blank data
+			continue;
+		}
 		else
 		{
 			bStartFound = true;
