@@ -415,6 +415,8 @@ bool pt_PieceTable::_realInsertStrux(PT_DocPosition dpos,
 		// this lets things like hitting two consecutive CR's and then comming
 		// back to the first empty paragraph behave as expected.
 
+		// fixme sevior here
+
 		if ((pf->getType()==pf_Frag::PFT_Text) && (fragOffset == 0) &&
 			(pf->getPrev()!=NULL) && (pf->getPrev()->getType()==pf_Frag::PFT_Strux))
 		{
@@ -425,6 +427,21 @@ bool pt_PieceTable::_realInsertStrux(PT_DocPosition dpos,
 			}
 		}
 	}
+	//
+	// Look if we're placing an endcell in an empty block. If so, 
+	// insert a format mark
+	//
+	if (pfsNew->getStruxType() == PTX_EndCell)
+	{
+		if((pf->getPrev()!=NULL) && (pf->getPrev()->getType()==pf_Frag::PFT_Strux))
+		{
+			pf_Frag_Strux *pfsStrux = static_cast<pf_Frag_Strux *>(pf->getPrev());
+			if(pfsStrux->getStruxType() == PTX_Block)
+			{
+				_insertFmtMarkAfterBlockWithNotify(pfsContainer,dpos,apFmtMark);
+			}
+		}
+	}
 
 	// insert this frag into the fragment list. Update the container strux as needed
 	_insertStrux(pf,fragOffset,pfsNew);
