@@ -244,104 +244,104 @@ return abi_widget_invoke_ex (w, #n, str, 0, 0); \
 // Here we define our EditMethods which will later be mapped back onto
 // Our AbiWidgetClass' member functions
 
-EM_VOID__BOOL(alignCenter);
-EM_VOID__BOOL(alignLeft);
-EM_VOID__BOOL(alignRight);
-EM_VOID__BOOL(alignJustify);
+EM_VOID__BOOL(alignCenter)
+EM_VOID__BOOL(alignLeft)
+EM_VOID__BOOL(alignRight)
+EM_VOID__BOOL(alignJustify)
 
-EM_VOID__BOOL(copy);
-EM_VOID__BOOL(cut);
-EM_VOID__BOOL(paste);
-EM_VOID__BOOL(pasteSpecial);
-EM_VOID__BOOL(selectAll);
-EM_VOID__BOOL(selectBlock);
-EM_VOID__BOOL(selectLine);
-EM_VOID__BOOL(selectWord);
+EM_VOID__BOOL(copy)
+EM_VOID__BOOL(cut)
+EM_VOID__BOOL(paste)
+EM_VOID__BOOL(pasteSpecial)
+EM_VOID__BOOL(selectAll)
+EM_VOID__BOOL(selectBlock)
+EM_VOID__BOOL(selectLine)
+EM_VOID__BOOL(selectWord)
 
-EM_VOID__BOOL(undo);
-EM_VOID__BOOL(redo);
+EM_VOID__BOOL(undo)
+EM_VOID__BOOL(redo)
 
-EM_CHARPTR__BOOL(insertData);
-EM_VOID__BOOL(insertSpace);
+EM_CHARPTR__BOOL(insertData)
+EM_VOID__BOOL(insertSpace)
 
-EM_VOID__BOOL(delBOB);
-EM_VOID__BOOL(delBOD);
-EM_VOID__BOOL(delBOL);
-EM_VOID__BOOL(delBOW);
-EM_VOID__BOOL(delEOB);
-EM_VOID__BOOL(delEOD);
-EM_VOID__BOOL(delEOL);
-EM_VOID__BOOL(delEOW);
-EM_VOID__BOOL(delLeft);
-EM_VOID__BOOL(delRight);
+EM_VOID__BOOL(delBOB)
+EM_VOID__BOOL(delBOD)
+EM_VOID__BOOL(delBOL)
+EM_VOID__BOOL(delBOW)
+EM_VOID__BOOL(delEOB)
+EM_VOID__BOOL(delEOD)
+EM_VOID__BOOL(delEOL)
+EM_VOID__BOOL(delEOW)
+EM_VOID__BOOL(delLeft)
+EM_VOID__BOOL(delRight)
 
-EM_VOID__BOOL(editHeader);
-EM_VOID__BOOL(editFooter);
-EM_VOID__BOOL(removeHeader);
-EM_VOID__BOOL(removeFooter);
+EM_VOID__BOOL(editHeader)
+EM_VOID__BOOL(editFooter)
+EM_VOID__BOOL(removeHeader)
+EM_VOID__BOOL(removeFooter)
 
-EM_VOID__BOOL(extSelBOB);
-EM_VOID__BOOL(extSelBOD);
-EM_VOID__BOOL(extSelBOL);
-EM_VOID__BOOL(extSelBOW);
-EM_VOID__BOOL(extSelEOB);
-EM_VOID__BOOL(extSelEOD);
-EM_VOID__BOOL(extSelEOL);
-EM_VOID__BOOL(extSelEOW);
-EM_VOID__BOOL(extSelLeft);
-EM_VOID__BOOL(extSelNextLine);
-EM_VOID__BOOL(extSelPageDown);
-EM_VOID__BOOL(extSelPageUp);
-EM_VOID__BOOL(extSelPrevLine);
-EM_VOID__BOOL(extSelRight);
-EM_VOID__BOOL(extSelScreenDown);
-EM_VOID__BOOL(extSelScreenUp);
-EM_INT_INT__BOOL(extSelToXY);
+EM_VOID__BOOL(extSelBOB)
+EM_VOID__BOOL(extSelBOD)
+EM_VOID__BOOL(extSelBOL)
+EM_VOID__BOOL(extSelBOW)
+EM_VOID__BOOL(extSelEOB)
+EM_VOID__BOOL(extSelEOD)
+EM_VOID__BOOL(extSelEOL)
+EM_VOID__BOOL(extSelEOW)
+EM_VOID__BOOL(extSelLeft)
+EM_VOID__BOOL(extSelNextLine)
+EM_VOID__BOOL(extSelPageDown)
+EM_VOID__BOOL(extSelPageUp)
+EM_VOID__BOOL(extSelPrevLine)
+EM_VOID__BOOL(extSelRight)
+EM_VOID__BOOL(extSelScreenDown)
+EM_VOID__BOOL(extSelScreenUp)
+EM_INT_INT__BOOL(extSelToXY)
 
-EM_VOID__BOOL(toggleBold);
-EM_VOID__BOOL(toggleBottomline);
-EM_VOID__BOOL(toggleInsertMode);
-EM_VOID__BOOL(toggleItalic);
-EM_VOID__BOOL(toggleOline);
-EM_VOID__BOOL(togglePlain);
-EM_VOID__BOOL(toggleStrike);
-EM_VOID__BOOL(toggleSub);
-EM_VOID__BOOL(toggleSuper);
-EM_VOID__BOOL(toggleTopline);
-EM_VOID__BOOL(toggleUline);
-EM_VOID__BOOL(toggleUnIndent);
+EM_VOID__BOOL(toggleBold)
+EM_VOID__BOOL(toggleBottomline)
+EM_VOID__BOOL(toggleInsertMode)
+EM_VOID__BOOL(toggleItalic)
+EM_VOID__BOOL(toggleOline)
+EM_VOID__BOOL(togglePlain)
+EM_VOID__BOOL(toggleStrike)
+EM_VOID__BOOL(toggleSub)
+EM_VOID__BOOL(toggleSuper)
+EM_VOID__BOOL(toggleTopline)
+EM_VOID__BOOL(toggleUline)
+EM_VOID__BOOL(toggleUnIndent)
 
-EM_VOID__BOOL(viewPara);
-EM_VOID__BOOL(viewPrintLayout);
-EM_VOID__BOOL(viewNormalLayout);
-EM_VOID__BOOL(viewWebLayout);
+EM_VOID__BOOL(viewPara)
+EM_VOID__BOOL(viewPrintLayout)
+EM_VOID__BOOL(viewNormalLayout)
+EM_VOID__BOOL(viewWebLayout)
 
-EM_VOID__BOOL(warpInsPtBOB);
-EM_VOID__BOOL(warpInsPtBOD);
-EM_VOID__BOOL(warpInsPtBOL);
-EM_VOID__BOOL(warpInsPtBOP);
-EM_VOID__BOOL(warpInsPtBOW);
-EM_VOID__BOOL(warpInsPtEOB);
-EM_VOID__BOOL(warpInsPtEOD);
-EM_VOID__BOOL(warpInsPtEOL);
-EM_VOID__BOOL(warpInsPtEOP);
-EM_VOID__BOOL(warpInsPtEOW);
-EM_VOID__BOOL(warpInsPtLeft);
-EM_VOID__BOOL(warpInsPtNextLine);
-EM_VOID__BOOL(warpInsPtNextPage);
-EM_VOID__BOOL(warpInsPtNextScreen);
-EM_VOID__BOOL(warpInsPtPrevLine);
-EM_VOID__BOOL(warpInsPtPrevPage);
-EM_VOID__BOOL(warpInsPtPrevScreen);
-EM_VOID__BOOL(warpInsPtRight);
-EM_INT_INT__BOOL(warpInsPtToXY);
+EM_VOID__BOOL(warpInsPtBOB)
+EM_VOID__BOOL(warpInsPtBOD)
+EM_VOID__BOOL(warpInsPtBOL)
+EM_VOID__BOOL(warpInsPtBOP)
+EM_VOID__BOOL(warpInsPtBOW)
+EM_VOID__BOOL(warpInsPtEOB)
+EM_VOID__BOOL(warpInsPtEOD)
+EM_VOID__BOOL(warpInsPtEOL)
+EM_VOID__BOOL(warpInsPtEOP)
+EM_VOID__BOOL(warpInsPtEOW)
+EM_VOID__BOOL(warpInsPtLeft)
+EM_VOID__BOOL(warpInsPtNextLine)
+EM_VOID__BOOL(warpInsPtNextPage)
+EM_VOID__BOOL(warpInsPtNextScreen)
+EM_VOID__BOOL(warpInsPtPrevLine)
+EM_VOID__BOOL(warpInsPtPrevPage)
+EM_VOID__BOOL(warpInsPtPrevScreen)
+EM_VOID__BOOL(warpInsPtRight)
+EM_INT_INT__BOOL(warpInsPtToXY)
 
-EM_VOID__BOOL(zoom100);
-EM_VOID__BOOL(zoom200);
-EM_VOID__BOOL(zoom50);
-EM_VOID__BOOL(zoom75);
-EM_VOID__BOOL(zoomWhole);
-EM_VOID__BOOL(zoomWidth);
+EM_VOID__BOOL(zoom100)
+EM_VOID__BOOL(zoom200)
+EM_VOID__BOOL(zoom50)
+EM_VOID__BOOL(zoom75)
+EM_VOID__BOOL(zoomWhole)
+EM_VOID__BOOL(zoomWidth)
 
 /**************************************************************************/
 /**************************************************************************/
