@@ -1244,24 +1244,24 @@ void		AP_UnixDialog_Options::_set##widget(const char *t) {	\
 	gtk_editable_insert_text(GTK_EDITABLE(m_text##widget), t, strlen(t), &pos);	\
 }
 
-DEFINE_GET_SET_BOOL(SpellCheckAsType);
-DEFINE_GET_SET_BOOL(SpellHideErrors);
-DEFINE_GET_SET_BOOL(SpellSuggest);
-DEFINE_GET_SET_BOOL(SpellMainOnly);
-DEFINE_GET_SET_BOOL(SpellUppercase);
-DEFINE_GET_SET_BOOL(SpellNumbers);
-DEFINE_GET_SET_BOOL(SpellInternet);
-DEFINE_GET_SET_BOOL(SmartQuotesEnable);
+DEFINE_GET_SET_BOOL(SpellCheckAsType)
+DEFINE_GET_SET_BOOL(SpellHideErrors)
+DEFINE_GET_SET_BOOL(SpellSuggest)
+DEFINE_GET_SET_BOOL(SpellMainOnly)
+DEFINE_GET_SET_BOOL(SpellUppercase)
+DEFINE_GET_SET_BOOL(SpellNumbers)
+DEFINE_GET_SET_BOOL(SpellInternet)
+DEFINE_GET_SET_BOOL(SmartQuotesEnable)
 
-DEFINE_GET_SET_BOOL(OtherDirectionRtl);
-DEFINE_GET_SET_BOOL(OtherSaveContextGlyphs);
-DEFINE_GET_SET_BOOL(OtherHebrewContextGlyphs);
+DEFINE_GET_SET_BOOL(OtherDirectionRtl)
+DEFINE_GET_SET_BOOL(OtherSaveContextGlyphs)
+DEFINE_GET_SET_BOOL(OtherHebrewContextGlyphs)
 
-DEFINE_GET_SET_BOOL(AutoSaveFile);
-DEFINE_GET_SET_BOOL(ShowSplash);
-DEFINE_GET_SET_BOOL(PrefsAutoSave);
-DEFINE_GET_SET_BOOL(ViewShowRuler);
-DEFINE_GET_SET_BOOL(ViewShowStatusBar);
+DEFINE_GET_SET_BOOL(AutoSaveFile)
+DEFINE_GET_SET_BOOL(ShowSplash)
+DEFINE_GET_SET_BOOL(PrefsAutoSave)
+DEFINE_GET_SET_BOOL(ViewShowRuler)
+DEFINE_GET_SET_BOOL(ViewShowStatusBar)
 
 void AP_UnixDialog_Options::_gatherAutoSaveFileExt(UT_String &stRetVal)
 {
@@ -1371,14 +1371,14 @@ void    AP_UnixDialog_Options::_setViewRulerUnits(UT_Dimension dim)
 		UT_DEBUGMSG(("option_menu_set_by_key failed\n"));
 }
 
-DEFINE_GET_SET_BOOL	(ViewCursorBlink);
+DEFINE_GET_SET_BOOL	(ViewCursorBlink)
 
-DEFINE_GET_SET_BOOL	(ViewAll);
-DEFINE_GET_SET_BOOL	(ViewHiddenText);
-DEFINE_GET_SET_BOOL	(ViewUnprintable);
-DEFINE_GET_SET_BOOL (AllowCustomToolbars);
-DEFINE_GET_SET_BOOL (EnableSmoothScrolling);
-DEFINE_GET_SET_BOOL (AutoLoadPlugins);
+DEFINE_GET_SET_BOOL	(ViewAll)
+DEFINE_GET_SET_BOOL	(ViewHiddenText)
+DEFINE_GET_SET_BOOL	(ViewUnprintable)
+DEFINE_GET_SET_BOOL (AllowCustomToolbars)
+DEFINE_GET_SET_BOOL (EnableSmoothScrolling)
+DEFINE_GET_SET_BOOL (AutoLoadPlugins)
 
 #undef DEFINE_GET_SET_BOOL
 
