@@ -1,19 +1,19 @@
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  */
 
@@ -27,7 +27,7 @@
 
 #include "xap_App.h"
 #include "xap_Win32App.h"
-#include "xap_Win32Frame.h"
+#include "xap_Win32FrameImpl.h"
 #include "fv_View.h"
 
 #include "ap_Strings.h"
@@ -40,10 +40,10 @@
 #include "ap_Win32Resources.rc2"
 #include "xap_Win32Toolbar_Icons.h"
 #include "xap_Win32Dlg_FontChooser.h"
+#include "xap_Win32DialogHelper.h"
+#include "ap_Win32App.h"
 
 #ifdef _MSC_VER
-// Workaround for Microsofts inability to follow international standards.
-#define for if (0) {} else for
 // MSVC++ warns about using 'this' in initializer list.
 #pragma warning(disable: 4355)
 #endif
@@ -107,6 +107,8 @@ void AP_Win32Dialog_Lists::runModeless(XAP_Frame * pFrame)
 
 BOOL AP_Win32Dialog_Lists::_onInitDialog(HWND hWnd, WPARAM wParam, LPARAM lParam)
 {
+	register int i;
+
 	m_hThisDlg = hWnd;
 	setbisCustomized(false);
 	clearDirty();
@@ -124,7 +126,7 @@ BOOL AP_Win32Dialog_Lists::_onInitDialog(HWND hWnd, WPARAM wParam, LPARAM lParam
 		AP_RID_DIALOG_LIST_SPIN_INDENT_ALIGN	// non-UDS_SETBUDDYINT
 	};
 
-	for (int i = 0; i < NrElements(rgSpinIDs); ++i)
+	for (i = 0; i < NrElements(rgSpinIDs); ++i)
 	{
 		HWND hWndSpin = GetDlgItem(hWnd, rgSpinIDs[i]);
 		if (hWndSpin)
@@ -136,6 +138,8 @@ BOOL AP_Win32Dialog_Lists::_onInitDialog(HWND hWnd, WPARAM wParam, LPARAM lParam
 			SendMessage(hWndSpin, UDM_SETRANGE, 0L, range);
 		}
 	}
+	
+	XAP_Win32DialogHelper::s_centerDialog(hWnd);			
 
 	const XAP_StringSet* pSS = m_pApp->getStringSet();
 
@@ -165,7 +169,7 @@ BOOL AP_Win32Dialog_Lists::_onInitDialog(HWND hWnd, WPARAM wParam, LPARAM lParam
 		AP_RID_DIALOG_LIST_RADIO_RESUME_PREV_LIST, AP_STRING_ID_DLG_Lists_Resume
 	};
 
-	for (int i = 0; i < NrElements(rgMapping); ++i)
+	for (i = 0; i < NrElements(rgMapping); ++i)
 	{
 		_win32Dialog.setControlText(rgMapping[i].controlId,
 									pSS->getValue(rgMapping[i].stringId));
@@ -212,6 +216,8 @@ BOOL AP_Win32Dialog_Lists::_onInitDialog(HWND hWnd, WPARAM wParam, LPARAM lParam
 	m_pAutoUpdateLists = UT_Timer::static_constructor(autoupdateLists, this);
 	m_bDestroy_says_stopupdating = false;
 	m_pAutoUpdateLists->set(500);	// auto-updater at 1/2 Hz
+	
+	
 
 	return 1;							// 1 == we did not call SetFocus()
 }
@@ -371,7 +377,7 @@ void AP_Win32Dialog_Lists::destroy(void)
 	m_bDestroy_says_stopupdating = true;
 	while (m_bAutoUpdate_happening_now == true) ;
 	m_pAutoUpdateLists->stop();
-	setAnswer(AP_Dialog_Lists::a_CLOSE);	
+	setAnswer(AP_Dialog_Lists::a_CLOSE);
 	if (IsWindow(m_hThisDlg))
 	{
 		_win32Dialog.destroyWindow();
@@ -421,15 +427,13 @@ void AP_Win32Dialog_Lists::activate(void)
 
 void AP_Win32Dialog_Lists::notifyActiveFrame(XAP_Frame *pFrame)
 {
-	XAP_Win32Frame* pWin32Frame = static_cast<XAP_Win32Frame *>(pFrame);
-
-	if (_win32Dialog.isParentFrame(*pWin32Frame))
+	if (_win32Dialog.isParentFrame(*pFrame))
 	{
 		return;
 	}
 
 	// change parent
-	_win32Dialog.setParentFrame(pWin32Frame);
+	_win32Dialog.setParentFrame(pFrame);
 	_win32Dialog.bringWindowToTop();
 	_updateCaption();
 
@@ -448,8 +452,7 @@ void AP_Win32Dialog_Lists::notifyCloseFrame(XAP_Frame *pFrame)
 	// such as when shutting down the application.
 	if (IsWindow(m_hThisDlg))
 	{
-		XAP_Win32Frame* pWin32Frame = static_cast<XAP_Win32Frame *>(pFrame);
-		if (_win32Dialog.isParentFrame(*pWin32Frame))
+		if (_win32Dialog.isParentFrame(*pFrame))
 		{
 			setbisCustomized(false);
 			setActiveFrame(getActiveFrame());
@@ -523,7 +526,7 @@ void AP_Win32Dialog_Lists::_onApply()
 	_win32Dialog.checkButton(AP_RID_DIALOG_LIST_RADIO_START_NEW_LIST, false);
 	_win32Dialog.checkButton(AP_RID_DIALOG_LIST_RADIO_APPLY_TO_CURRENT_LIST, true);
 	_win32Dialog.checkButton(AP_RID_DIALOG_LIST_RADIO_RESUME_PREV_LIST, false);
-	
+
 	_enableControls();
 
 	PopulateDialogData();
@@ -631,12 +634,9 @@ void AP_Win32Dialog_Lists::_fillStyleList(int iType)
 		AP_STRING_ID_DLG_Lists_Lower_Case_List,
 		AP_STRING_ID_DLG_Lists_Upper_Case_List,
 		AP_STRING_ID_DLG_Lists_Lower_Roman_List,
-		AP_STRING_ID_DLG_Lists_Upper_Roman_List
-#ifdef BIDI_ENABLED
-		,AP_STRING_ID_DLG_Lists_Arabic_List,
-
+		AP_STRING_ID_DLG_Lists_Upper_Roman_List,
+		AP_STRING_ID_DLG_Lists_Arabic_List,
 		AP_STRING_ID_DLG_Lists_Hebrew_List
-#endif
 	};
 
 	const XAP_String_Id*	pIDs;
@@ -666,7 +666,7 @@ void AP_Win32Dialog_Lists::_fillStyleList(int iType)
 	HDC hDCcombo = GetDC(hComboStyle);
 	HDC hDC = CreateCompatibleDC(hDCcombo);
 	ReleaseDC(hComboStyle, hDCcombo);
-	
+
 	HFONT hFont = (HFONT)GetStockObject(DEFAULT_GUI_FONT);
 	SelectObject(hDC, hFont);
 
@@ -718,13 +718,9 @@ void AP_Win32Dialog_Lists::_styleChanged()
 	setNewListType(_getListTypeFromCombos());
 	setbisCustomized(false);
 /*
-#ifdef BIDI_ENABLED
-
 	// have to do this, since for instance the decimal delimter can change
 
 	fillUncustomizedValues();
-
-#endif
 */
 	_previewExposed();
 	_setDisplayedData();
@@ -780,7 +776,7 @@ void AP_Win32Dialog_Lists::_enableCustomControls(bool bEnable)
 void AP_Win32Dialog_Lists::_updateCaption()
 {
 	ConstructWindowName();
-	_win32Dialog.setDialogTitle(getWindowName());
+	_win32Dialog.setDialogTitle((LPCSTR)(AP_Win32App::s_fromUTF8ToAnsi( getWindowName())).c_str());	
 }
 
 void AP_Win32Dialog_Lists::_previewExposed()
@@ -849,7 +845,7 @@ void AP_Win32Dialog_Lists::_getDisplayedData(UT_sint32 controlId)
 	if (controlId == -1 || controlId == AP_RID_DIALOG_LIST_EDIT_LIST_ALIGN)
 	{
 		_win32Dialog.getControlText(AP_RID_DIALOG_LIST_EDIT_LIST_ALIGN, szTmp, 30);
-		setfAlign((float)UT_convertDimensionless(szTmp));	
+		setfAlign((float)UT_convertDimensionless(szTmp));
 	}
 
 	if (controlId == -1 || controlId == AP_RID_DIALOG_LIST_EDIT_INDENT_ALIGN)
@@ -863,11 +859,11 @@ void AP_Win32Dialog_Lists::_getDisplayedData(UT_sint32 controlId)
 		controlId == AP_RID_DIALOG_LIST_EDIT_INDENT_ALIGN)
 	{
 		if( getfAlign() < 0.0 )
-		{	
+		{
 			setfAlign(0.0);
 			_win32Dialog.setControlText(AP_RID_DIALOG_LIST_EDIT_INDENT_ALIGN,
 								UT_convertToDimensionlessString(0.0, ".2"));
-		}                                       
+		}
 
 		if ( (getfIndent() + getfAlign()) < 0.0 )
 		{
@@ -1046,7 +1042,7 @@ void AP_Win32Dialog_Lists::_selectFont()
 	pDialog->setGraphicsContext(pView->getGraphics());
 	pDialog->runModal(pFrame);
 
-	if (pDialog->getAnswer() != XAP_Dialog_FontChooser::a_OK && 
+	if (pDialog->getAnswer() != XAP_Dialog_FontChooser::a_OK &&
 		pDialog->getAnswer() != XAP_Dialog_FontChooser::a_YES)
 	{
 		return;
