@@ -170,11 +170,12 @@ ap_bs_Mouse MouseTable[] =
 	{_CU _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
 	{_CT _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
 	{_CT _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CM _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
+	{_CM _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
 	{_CL _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
 	{_CL _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
 	{_CR _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
-	{_CM _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
-	{_CM _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CR _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
 	{_CI _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
 	{_CI _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
 	{_CZ _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
@@ -183,6 +184,12 @@ ap_bs_Mouse MouseTable[] =
 	{_CF _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
 	{_CH _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
 	{_CH _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CV _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
+	{_CV _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CTV _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
+	{_CTV _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
+	{_CTH _B4,	{ "scrollWheelMouseUp",		"scrollWheelMouseUp",			"",		"",			"",			""				}},
+	{_CTH _B4 _C,{ "zoomIn",		            "zoomIn",           			"",		"",			"",			""				}},
 
 
 //  Button-5, Mouse wheel (3 lines down)
@@ -190,10 +197,12 @@ ap_bs_Mouse MouseTable[] =
 	{_CU _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
 	{_CT _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
 	{_CT _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
-	{_CL _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
-	{_CL _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
 	{_CM _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
 	{_CM _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
+	{_CL _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
+	{_CL _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
+	{_CR _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
+	{_CR _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
 	{_CI _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
 	{_CI _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
 	{_CZ _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
@@ -202,6 +211,12 @@ ap_bs_Mouse MouseTable[] =
 	{_CF _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
 	{_CH _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
 	{_CH _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
+	{_CV _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
+	{_CV _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
+	{_CTV _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
+	{_CTV _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
+	{_CTH _B5,	{ "scrollWheelMouseDown",		"scrollWheelMouseDown",			"",		"",			"",			""				}},
+	{_CTH _B5 _C,{ "zoomOut",		            "zoomOut",           			"",		"",			"",			""				}},
 
 #if defined(PT_TEST) || defined(FMT_TEST) || defined(UT_TEST)
 //  { context		{ click			doubleclick		drag,		dbldrag,	release,	doublerelease	}},
@@ -369,7 +384,7 @@ ap_bs_Char CharTable[] =
 	{0x2b, /* +      */ { "insertData",			"",					"",				""					}},
 	{0x2c, /* ,      */ { "insertData",			"",					"",				""					}},
 	{0x2d, /* -      */ { "insertData",			"toggleSub",		"zoomOut",		""					}},
-	{0x2e, /* .      */ { "insertData",			"",					"",				""					}},
+	{0x2e, /* .      */ { "insertData",			"pasteSpecial",		"",				""					}},
 	{0x2f, /* /      */ { "insertData",			"",					"",				""					}},
 	{0x30, /* 0      */ { "insertData",			"",					DO_NOT_USE,		""					}},
 	{0x31, /* 1      */ { "insertData",			"singleSpace",		DO_NOT_USE,		"setStyleHeading1"	}},
@@ -409,7 +424,7 @@ ap_bs_Char CharTable[] =
 	{0x53, /* S      */ { "insertData",			"fileSave",			DO_NOT_USE,		""					}},
 	{0x54, /* T      */ { "insertData",			"toggleOline",		DO_NOT_USE,		""					}},
 	{0x55, /* U      */ { "insertData",			"toggleUline",		DO_NOT_USE,		""					}},
-	{0x56, /* V      */ { "insertData",			"paste",			DO_NOT_USE,		"pasteSpecial"					}},
+	{0x56, /* V      */ { "insertData",			"paste",			DO_NOT_USE,		""					}},
 	{0x57, /* W      */ { "insertData",			"closeWindow",		DO_NOT_USE,		""					}},
 	{0x58, /* X      */ { "insertData",			"cut",				DO_NOT_USE,		""					}},
 	{0x59, /* Y      */ { "insertData",			"redo",				DO_NOT_USE,		""					}},
@@ -441,7 +456,7 @@ ap_bs_Char CharTable[] =
 	{0x73, /* s      */ { "insertData",			"fileSave",			DO_NOT_USE,		""					}},
 	{0x74, /* t      */ { "insertData",			"toggleOline",		DO_NOT_USE,		""					}},
 	{0x75, /* u      */ { "insertData",			"toggleUline",		DO_NOT_USE,		""					}},
-	{0x76, /* v      */ { "insertData",			"paste",			DO_NOT_USE,		"pasteSpecial"					}},
+	{0x76, /* v      */ { "insertData",			"paste",			DO_NOT_USE,		""					}},
 	{0x77, /* w      */ { "insertData",			"closeWindow",		DO_NOT_USE,		""					}},
 	{0x78, /* x      */ { "insertData",			"cut",				DO_NOT_USE,		""					}},
 	{0x79, /* y      */ { "insertData",			"redo",				DO_NOT_USE,		""					}},
