@@ -1091,6 +1091,27 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_InTable)
 }
 
 
+Defun_EV_GetMenuItemState_Fn(ap_GetState_TableOK)
+{
+	ABIWORD_VIEW;
+	UT_return_val_if_fail (pView, EV_MIS_Gray);
+
+	if(pView->isInTable(pView->getPoint()-1) && pView->isInTable() && pView->isHdrFtrEdit())
+	{
+		return EV_MIS_Gray;
+	}
+	else if(pView->isInFootnote())
+	{
+		return EV_MIS_Gray;
+	}
+	else if(pView->isInEndnote())
+	{
+		return EV_MIS_Gray;
+	}
+    return EV_MIS_ZERO;
+}
+
+
 Defun_EV_GetMenuItemState_Fn(ap_GetState_InFootnote)
 {
 	ABIWORD_VIEW;
@@ -1106,6 +1127,29 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_InFootnote)
 	}
 }
 
+Defun_EV_GetMenuItemState_Fn(ap_GetState_BreakOK)
+{
+	ABIWORD_VIEW;
+	UT_return_val_if_fail (pView, EV_MIS_Gray);
+
+	if(pView->isInFootnote())
+	{
+		return EV_MIS_Gray;
+	}
+	if(pView->isInEndnote())
+	{
+		return EV_MIS_Gray;
+	}
+	else if(pView->isInTable(pView->getPoint()-1) && pView->isInTable())
+	{
+		return EV_MIS_Gray;
+	}
+	else
+	{
+		return EV_MIS_ZERO;
+	}
+}
+
 // HACK TO ALWAYS DISABLE A MENU ITEM... DELETE ME
 Defun_EV_GetMenuItemState_Fn(ap_GetState_AlwaysDisabled)
 {
@@ -1139,29 +1183,29 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_Zoom)
 	switch(id)
 	{
 	case AP_MENU_ID_VIEW_ZOOM_200:
-		if (pFrame->getZoomPercentage() == 200)
+		if (pFrame->getZoomPercentage() == 200 && (pFrame->getZoomType() == XAP_Frame::z_PERCENT || pFrame->getZoomType() == XAP_Frame::z_200))
 			s = EV_MIS_Toggled;
 		break;
 	case AP_MENU_ID_VIEW_ZOOM_100:
-		if (pFrame->getZoomPercentage() == 100)
+		if (pFrame->getZoomPercentage() == 100 && (pFrame->getZoomType() == XAP_Frame::z_PERCENT || pFrame->getZoomType() == XAP_Frame::z_100))
 			s = EV_MIS_Toggled;
 		break;
 	case AP_MENU_ID_VIEW_ZOOM_75:
-		if (pFrame->getZoomPercentage() == 75)
+		if (pFrame->getZoomPercentage() == 75 && (pFrame->getZoomType() == XAP_Frame::z_PERCENT || pFrame->getZoomType() == XAP_Frame::z_75))
 			s = EV_MIS_Toggled;
 		break;
 	case AP_MENU_ID_VIEW_ZOOM_50:
-		if (pFrame->getZoomPercentage() == 50)
+		if (pFrame->getZoomPercentage() == 50 && pFrame->getZoomType() == XAP_Frame::z_PERCENT)
 			s = EV_MIS_Toggled;
 		break;
 	case AP_MENU_ID_VIEW_ZOOM_WHOLE:
 		xxx_UT_DEBUGMSG(("Whole: %d %d\n", pFrame->getZoomPercentage(), pView->calculateZoomPercentForWholePage()));
-		if (pFrame->getZoomPercentage() == pView->calculateZoomPercentForWholePage())
+		if (pFrame->getZoomType() == XAP_Frame::z_WHOLEPAGE)
 			s = EV_MIS_Toggled;
 		break;
 	case AP_MENU_ID_VIEW_ZOOM_WIDTH:
 		xxx_UT_DEBUGMSG(("Width: %d %d\n", pFrame->getZoomPercentage(), pView->calculateZoomPercentForPageWidth()));
-		if (pFrame->getZoomPercentage() == pView->calculateZoomPercentForPageWidth())
+		if (pFrame->getZoomType() == XAP_Frame::z_PAGEWIDTH)
 			s = EV_MIS_Toggled;
 		break;
 	default:
