@@ -772,12 +772,36 @@ Defun_EV_GetToolbarItemState_Fn(ap_ToolbarGetState_Table)
   ABIWORD_VIEW;
   UT_ASSERT(pView);
   
-  if(pView->isInTable())
-    return EV_TIS_ZERO;
-  
+  if(pView->isInTable(pView->getPoint()-1) && pView->isInTable() )
+  {
+	  return EV_TIS_ZERO;
+  }
   return EV_TIS_Gray;
 }
 
+
+Defun_EV_GetToolbarItemState_Fn(ap_ToolbarGetState_TableOK)
+{
+  ABIWORD_VIEW;
+  UT_return_val_if_fail (pView, EV_TIS_Gray);
+  
+  if(pView->isInTable(pView->getPoint()-1) && pView->isInTable() && pView->isHdrFtrEdit())
+  {
+	  return EV_TIS_Gray;
+  }
+  else if(pView->isInFootnote())
+  {
+	  return EV_TIS_Gray;
+  }
+  else if(pView->isInEndnote())
+  {
+	  return EV_TIS_Gray;
+  } 
+
+  return EV_TIS_ZERO;
+}
+
+
 // HACK TO ALWAYS DISABLE A TOOLBAR ITEM... DELETE ME
 Defun_EV_GetToolbarItemState_Fn(ap_ToolbarGetState_AlwaysDisabled)
 {
