@@ -1,5 +1,6 @@
 /* AbiWord
- * Copyright (C) 1998 AbiSource, Inc.
+ * Copyright (C) 1998-2000 AbiSource, Inc.
+ * Copyright (C) 2003 Tomas Frydrych <tomas@frydrych.uklinux.net> 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,6 +19,7 @@
  */
 
 #include <string.h>
+#include "ut_debugmsg.h"
 #include "ut_string.h"
 #include "ut_bytebuf.h"
 #include "ut_base64.h"
@@ -38,21 +40,27 @@
 #include "xap_Dlg_Encoding.h"
 #include "ap_Prefs.h"
 #include "ut_string_class.h"
-
 #ifdef WIN32
-#include "ut_Win32OS.h"
+  #include "ut_Win32OS.h"
 #endif
+#include <fribidi.h>
+
 
 /*****************************************************************/
 /*****************************************************************/
 
 IE_Exp_Text::IE_Exp_Text(PD_Document * pDocument, bool bEncoded)
 	: IE_Exp(pDocument),
-	  m_pListener(NULL)
+	  m_pListener(NULL),
+	  m_bIsEncoded(false),
+	  m_szEncoding(0),
+	  m_bExplicitlySetEncoding(false),
+	  m_bIs16Bit(false),
+	  m_bUnicode(false),
+	  m_bBigEndian(false),
+	  m_bUseBOM(false)
 {
-	UT_ASSERT(pDocument);
-
-	m_error = 0;
+	m_error = UT_OK;
 
 	// Get encoding dialog prefs setting
 	bool bAlwaysPrompt = false;
@@ -67,9 +75,50 @@ IE_Exp_Text::IE_Exp_Text(PD_Document * pDocument, bool bEncoded)
 	_setEncoding(szEncodingName);
 }
 
+IE_Exp_Text::IE_Exp_Text(PD_Document * pDocument, const char * encoding)
+  : IE_Exp(pDocument),
+    m_pListener(NULL),
+    m_bIsEncoded(false),
+    m_szEncoding(0),
+    m_bExplicitlySetEncoding(false),
+    m_bIs16Bit(false),
+    m_bUnicode(false),
+    m_bBigEndian(false),
+	m_bUseBOM(false)
+{
+  m_error = UT_OK;
+  
+  m_bIsEncoded = ((encoding != NULL) && (strlen(encoding) > 0));
+  
+  if ( m_bIsEncoded )
+    {
+      m_bExplicitlySetEncoding = true;
+     _setEncoding(encoding);
+    }
+}
+
 /*****************************************************************/
 /*****************************************************************/
 
+IE_Exp_Text_Sniffer::IE_Exp_Text_Sniffer ()
+	: IE_ExpSniffer(IE_IMPEXPNAME_TEXT)
+{
+	// 
+}
+
+UT_Confidence_t IE_Exp_Text_Sniffer::supportsMIME (const char * szMIME)
+{
+	if (UT_strcmp (szMIME, IE_MIME_Text) == 0)
+		{
+			return UT_CONFIDENCE_GOOD;
+		}
+	if (strncmp (szMIME, "text/", 5) == 0)
+		{
+			return UT_CONFIDENCE_SOSO;
+		}
+	return UT_CONFIDENCE_ZILCH;
+}
+
 /*!
   Check filename extension for filetypes we support
  \param szSuffix Filename extension
@@ -100,6 +149,12 @@ bool IE_Exp_Text_Sniffer::getDlgLabels(const char ** pszDesc,
 /*****************************************************************/
 /*****************************************************************/
 
+IE_Exp_EncodedText_Sniffer::IE_Exp_EncodedText_Sniffer ()
+	: IE_ExpSniffer(IE_IMPEXPNAME_TEXTENC)
+{
+	// 
+}
+
 /*!
   Check filename extension for filetypes we support
  \param szSuffix Filename extension
@@ -132,7 +187,17 @@ bool IE_Exp_EncodedText_Sniffer::getDlgLabels(const char ** pszDesc,
 
 PL_Listener * IE_Exp_Text::_constructListener(void)
 {
-	return new Text_Listener(getDoc(),this,(getDocRange()!=NULL),m_szEncoding,m_bIs16Bit,m_bUseBOM,m_bBigEndian);
+	if (!m_bExplicitlySetEncoding) {
+		const UT_UTF8String * prop;
+
+		prop = getProperty ("encoding");
+		if (prop) {
+			_setEncoding (prop->utf8_str());
+		}
+	}
+
+	return new Text_Listener(getDoc(),this,(getDocRange()!=NULL),m_szEncoding,
+							 m_bIs16Bit,m_bUnicode,m_bUseBOM,m_bBigEndian);
 }
 
 // TODO This function is also used for Copy and Paste.
@@ -177,10 +242,13 @@ UT_Error IE_Exp_Text::_writeDocument(void)
 bool IE_Exp_Text::_openFile(const char * szFilename)
 {
 	// Don't call base method if user cancels encoding dialog
-	if (!m_bIsEncoded || _doEncodingDialog(m_szEncoding))
+	if (!m_bIsEncoded || m_bExplicitlySetEncoding || _doEncodingDialog(m_szEncoding))
 		return IE_Exp::_openFile(szFilename);
 	else
+	{
+		_cancelExport ();
 		return false;
+	}
 }
 
 /*!
@@ -198,13 +266,13 @@ bool IE_Exp_Text::_doEncodingDialog(const char *szEncoding)
 
 	XAP_Dialog_Encoding * pDialog
 		= static_cast<XAP_Dialog_Encoding *>(pDialogFactory->requestDialog(id));
-	UT_ASSERT(pDialog);
+	UT_return_val_if_fail(pDialog, false);
 
 	pDialog->setEncoding(szEncoding);
 
 	// run the dialog
 	XAP_Frame * pFrame = getDoc()->getApp()->getLastFocussedFrame();
-	UT_ASSERT(pFrame);
+	UT_return_val_if_fail(pFrame, false);
 
 	pDialog->runModal(pFrame);
 
@@ -218,7 +286,7 @@ bool IE_Exp_Text::_doEncodingDialog(const char *szEncoding)
 		static UT_String szEnc;
 
 		s = pDialog->getEncoding();
-		UT_ASSERT (s);
+		UT_return_val_if_fail (s, false);
 
 		szEnc = s;
 		_setEncoding(szEnc.c_str());
@@ -253,6 +321,7 @@ void IE_Exp_Text::_setEncoding(const char *szEncoding)
 #else
 		m_bUseBOM = false;
 #endif
+		m_bUnicode = true;
 	}
 	else if (szEncoding && !strcmp(szEncoding,XAP_EncodingManager::get_instance()->getUCS2BEName()))
 	{
@@ -263,6 +332,15 @@ void IE_Exp_Text::_setEncoding(const char *szEncoding)
 #else
 		m_bUseBOM = false;
 #endif
+		m_bUnicode = true;
+	}
+	else if(szEncoding && !UT_strnicmp(szEncoding,"UTF-",4))
+	{
+		// TODO -- can encoding be utf-16 or utf-32?
+		m_bIs16Bit = false;
+		m_bBigEndian = false;
+		m_bUseBOM = false;
+		m_bUnicode = true;
 	}
 	else
 	{
@@ -270,6 +348,7 @@ void IE_Exp_Text::_setEncoding(const char *szEncoding)
 		// These are currently meaningless when not in a Unicode encoding
 		m_bBigEndian = false;
 		m_bUseBOM = false;
+		m_bUnicode = false;
 	}
 }
 
@@ -283,24 +362,6 @@ void IE_Exp_Text::_setEncoding(const char *szEncoding)
  */
 void Text_Listener::_genBOM(void)
 {
-	// TODO iconv (at least libiconv) actually converts BOM to nothing at all ):
-#if 0
-	UT_UCSChar wcBOM[2] = {0,0};
-	UT_UCSChar *pWC;
-	char *pMB = static_cast<char *>(m_mbBOM);
-	int mbLen;
-
-	wcBOM[0] = UCS_BOM;
-
-	for (pWC = wcBOM; *pWC; ++pwC)
-	{
-		if (_wctomb(pMB,mbLen,static_cast<wchar_t>(*pWC)))
-			pMB += mbLen;
-		else
-			UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
-	}
-	m_iBOMLen = pMB - m_mbBOM;
-#else
 	// Hard-coded BOM values
 	if (m_bIs16Bit)
 	{
@@ -323,7 +384,6 @@ void Text_Listener::_genBOM(void)
 		m_iBOMLen = 3;
 	}
 	// TODO UTF-7, UCS-4, UTF-32
-#endif
 }
 
 /*!
@@ -334,27 +394,27 @@ void Text_Listener::_genBOM(void)
 void Text_Listener::_genLineBreak(void)
 {
 	char *pMB = static_cast<char *>(m_mbLineBreak);
-	UT_UCSChar *pWC = 0;
+	const UT_UCSChar *pWC = 0;
 	int mbLen = 0;
 
 	// TODO Old Mac should use "\r".  Mac OSX should Use U+2028 or U+2029.
 #ifdef WIN32
-	UT_UCSChar wcLineBreak[3] = {'\r', '\n', 0};
+	static const UT_UCSChar wcLineBreak[3] = {'\r', '\n', 0};
 #else
-	UT_UCSChar wcLineBreak[3] = {'\n', 0, 0};
+	static const UT_UCSChar wcLineBreak[3] = {'\n', 0, 0};
 #endif
 
 	for (pWC = wcLineBreak; *pWC; ++pWC)
 	{
-		if (_wctomb(pMB,mbLen,static_cast<wchar_t>(*pWC)))
+		if (_wctomb(pMB,mbLen,*pWC))
 			pMB += mbLen;
 		else
-			UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		  UT_ASSERT_NOT_REACHED();
 	}
 
 	m_iLineBreakLen = pMB - m_mbLineBreak;
 
-	UT_ASSERT(m_iLineBreakLen && m_iLineBreakLen < 20);
+	UT_ASSERT_HARMLESS(m_iLineBreakLen && m_iLineBreakLen < 20);
 }
 
 /*!
@@ -393,14 +453,14 @@ void Text_Listener::_outputData(const UT_UCSChar * data, UT_uint32 length)
 			bBuf.append(reinterpret_cast<UT_Byte *>(m_mbLineBreak),m_iLineBreakLen);
 		else
 		{
-			if (!_wctomb(pC,mbLen,static_cast<wchar_t>(*pData)))
+			if (!_wctomb(pC,mbLen,*pData))
 			{
-				UT_ASSERT(!m_bIs16Bit);
+				UT_ASSERT_HARMLESS(!m_bIs16Bit);
 				mbLen=1;
 				pC[0]='?';
 				m_wctomb.initialize();
 			}
-			UT_ASSERT(mbLen>=1);
+			UT_ASSERT_HARMLESS(mbLen>=1);
 			bBuf.append(reinterpret_cast<const UT_Byte *>(pC),mbLen);
 		}
 	}
@@ -414,26 +474,144 @@ void Text_Listener::_closeBlock(void)
 		return;
 
 	if (!m_bFirstWrite)
-	  _genLineBreak ();
-
-	//UT_ASSERT(!m_bFirstWrite);
-	//UT_ASSERT(m_iLineBreakLen);
-
-	m_pie->write(static_cast<const char *>(m_mbLineBreak),m_iLineBreakLen);
+	{
+		m_pie->write(static_cast<const char *>(m_mbLineBreak),m_iLineBreakLen);
+		if (m_bBreakExtra)
+			m_pie->write(static_cast<const char *>(m_mbLineBreak),m_iLineBreakLen);
+	}
 
 	m_bInBlock = false;
+	m_eDirOverride = DO_UNSET;
+	m_eDirMarkerPending = DO_UNSET;
 	return;
 }
 
+void Text_Listener::_handleDirMarker(PT_AttrPropIndex api)
+{
+	const PP_AttrProp * pAP = NULL;
+	bool bHaveProp = m_pDocument->getAttrProp (api, &pAP);
+	
+	UT_UCS4Char * pMarker = NULL;
+		
+	if (bHaveProp && pAP)
+	{
+		UT_UCS4Char cRLO = UCS_RLO;
+		UT_UCS4Char cLRO = UCS_LRO;
+		UT_UCS4Char cPDF = UCS_PDF;
+
+		const XML_Char *szValue = NULL;
+		if(pAP->getProperty("dir-override", szValue))
+		{
+			if(m_eDirOverride == DO_UNSET)
+			{
+				if(!UT_stricmp(szValue, "rtl"))
+				{
+					m_eDirOverride = DO_RTL;
+					pMarker = &cRLO;
+				}
+				else if(!UT_stricmp(szValue, "ltr"))
+				{
+					m_eDirOverride = DO_LTR;
+					pMarker = &cLRO;
+				}
+			}
+			else if(m_eDirOverride == DO_RTL)
+			{
+				if(!UT_stricmp(szValue, "rtl"))
+				{
+					// no change
+				}
+				else if(!UT_stricmp(szValue, "ltr"))
+				{
+					m_eDirOverride = DO_LTR;
+					pMarker = &cLRO;
+				}
+			}
+			else if(m_eDirOverride == DO_LTR)
+			{
+				if(!UT_stricmp(szValue, "ltr"))
+				{
+					// no change
+				}
+				else if(!UT_stricmp(szValue, "rtl"))
+				{
+					m_eDirOverride = DO_RTL;
+					pMarker = &cRLO;
+				}
+			}
+			else
+			{
+				UT_DEBUGMSG(("Text_Listener::_handleDirMarker: dir-override value '%s'\n",
+							 szValue));
+				UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+			}
+		}
+		else
+		{
+			if(m_eDirOverride != DO_UNSET)
+			{
+				m_eDirOverride = DO_UNSET;
+				pMarker = &cPDF;
+			}
+		}
+	}
+	else
+	{
+		UT_DEBUGMSG(("Text_Listener::_handleDirMarker: no props! (bHaveProp %d, pAP 0x%x)\n",
+					 bHaveProp, pAP));
+		UT_ASSERT( UT_SHOULD_NOT_HAPPEN );
+	}
+
+	// first see if there is a pending marker (for block direction)
+	// and handle it
+	if(pMarker && m_eDirMarkerPending != DO_UNSET)
+	{
+		UT_UCS4Char cRLM = UCS_RLM;
+		UT_UCS4Char cLRM = UCS_LRM;
+
+		if(m_eDirMarkerPending == DO_RTL && *pMarker == UCS_RLO)
+		{
+			//the override corresponds to the marker, no marker needed
+			m_eDirMarkerPending = DO_UNSET;
+		}
+		else if(m_eDirMarkerPending == DO_RTL && *pMarker == UCS_LRO)
+		{
+			//need to issue marker
+			_outputData(&cRLM, 1);
+			m_eDirMarkerPending = DO_UNSET;
+		}
+		else if(m_eDirMarkerPending == DO_LTR && *pMarker == UCS_LRO)
+		{
+			//the override corresponds to the marker, no marker needed
+			m_eDirMarkerPending = DO_UNSET;
+		}
+		else if(m_eDirMarkerPending == DO_LTR && *pMarker == UCS_RLO)
+		{
+			//need to issue marker
+			_outputData(&cLRM, 1);
+			m_eDirMarkerPending = DO_UNSET;
+		}
+	}
+
+	if(pMarker)
+	{
+		_outputData(pMarker, 1);
+	}
+}
+
+
+
 Text_Listener::Text_Listener(PD_Document * pDocument,
 							 IE_Exp_Text * pie,
 							 bool bToClipboard,
 							 const char *szEncoding,
 							 bool bIs16Bit,
+							 bool bUnicode,
 							 bool bUseBOM,
 							 bool bBigEndian)
 	: m_pDocument(pDocument),
 	  m_pie(pie),
+	  m_wctomb(XAP_EncodingManager::get_instance()->getNative8BitEncodingName()),
 	  // when we are going to the clipboard, we should implicitly
 	  // assume that we are starting in the middle of a block.
 	  // when going to a file we should not.
@@ -445,8 +623,39 @@ Text_Listener::Text_Listener(PD_Document * pDocument,
 	  m_szEncoding(szEncoding),
 	  m_bIs16Bit(bIs16Bit),
 	  m_bBigEndian(bBigEndian),
-	  m_bUseBOM(bToClipboard ? false : bUseBOM)
+	  m_bUnicode(bUnicode),
+	  m_bUseBOM(bToClipboard ? false : bUseBOM),
+	  m_bBreakExtra(false),
+	  m_eDirOverride(DO_UNSET),
+	  m_eDirMarkerPending(DO_UNSET),
+	  m_eSectionDir(DO_UNSET),
+	  m_eDocDir(DO_UNSET)
 {
+	PT_AttrPropIndex api = m_pDocument->getAttrPropIndex();
+	const PP_AttrProp * pAP = NULL;
+	bool bHaveProp = m_pDocument->getAttrProp (api, &pAP);
+
+	if (bHaveProp && pAP)
+	{
+		const XML_Char *szValue = NULL;
+		if(pAP->getProperty("dom-dir", szValue))
+		{
+			if(!UT_stricmp("rtl",szValue))
+			{
+				m_eDocDir = DO_RTL;
+			}
+			else
+			{
+				m_eDocDir = DO_LTR;
+			}
+		}
+		else
+		{
+			// something wrong, default to LTR
+			m_eSectionDir = DO_LTR;
+		}
+				
+	}
 }
 
 bool Text_Listener::populate(PL_StruxFmtHandle /*sfh*/,
@@ -458,15 +667,52 @@ bool Text_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 		{
 			const PX_ChangeRecord_Span * pcrs = static_cast<const PX_ChangeRecord_Span *>(pcr);
 
+			PT_AttrPropIndex api = pcr->getIndexAP();
+			_handleDirMarker(api);
+
 			PT_BufIndex bi = pcrs->getBufIndex();
-			_outputData(m_pDocument->getPointer(bi),pcrs->getLength());
+			const UT_UCS4Char * pData = m_pDocument->getPointer(bi);
+
+			// first see if there is a pending marker (for block direction)
+			// and handle it
+			if(pData && m_eDirMarkerPending != DO_UNSET)
+			{
+				UT_UCS4Char cRLM = UCS_RLM;
+				UT_UCS4Char cLRM = UCS_LRM;
+
+				FriBidiCharType type = fribidi_get_type(static_cast<FriBidiChar>(*pData));
+				
+				if(m_eDirMarkerPending == DO_RTL && type == FRIBIDI_TYPE_RTL)
+				{
+					//the override corresponds to the marker, no marker needed
+					m_eDirMarkerPending = DO_UNSET;
+				}
+				else if(m_eDirMarkerPending == DO_RTL && type == FRIBIDI_TYPE_LTR)
+				{
+					//need to issue marker
+					_outputData(&cRLM, 1);
+					m_eDirMarkerPending = DO_UNSET;
+				}
+				else if(m_eDirMarkerPending == DO_LTR && type == FRIBIDI_TYPE_LTR)
+				{
+					//the override corresponds to the marker, no marker needed
+					m_eDirMarkerPending = DO_UNSET;
+				}
+				else if(m_eDirMarkerPending == DO_LTR && type == FRIBIDI_TYPE_RTL)
+				{
+					//need to issue marker
+					_outputData(&cLRM, 1);
+					m_eDirMarkerPending = DO_UNSET;
+				}
+			}
+			
+			_outputData(pData,pcrs->getLength());
 
 			return true;
 		}
 
 	case PX_ChangeRecord::PXT_InsertObject:
 		{
-#if 1
 			// TODO decide how to indicate objects in text output.
 
 			const PX_ChangeRecord_Object * pcro = static_cast<const PX_ChangeRecord_Object *>(pcr);
@@ -480,9 +726,9 @@ bool Text_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 			case PTO_Field:
 				// Lossy, but pretty much unavoidable
 				field = pcro->getField();
-				UT_ASSERT(field);
+				UT_return_val_if_fail(field, false);
 //
-// Sevior: This makes me really unconfortable. I this will oly work for piecetable
+// Sevior: This makes me really unconfortable. I this will only work for piecetable
 // fields
 //
 				if(field->getValue() != NULL)
@@ -497,12 +743,9 @@ bool Text_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 				return true;
 
 			default:
-				UT_ASSERT(0);
+				UT_ASSERT_NOT_REACHED();
 				return false;
 			}
-#else
-			return true;
-#endif
 		}
 
 	case PX_ChangeRecord::PXT_InsertFmtMark:
@@ -524,15 +767,35 @@ bool Text_Listener::populateStrux(PL_StruxDocHandle /*sdh*/,
 
 	switch (pcrx->getStruxType())
 	{
+	case PTX_SectionEndnote:
+	case PTX_SectionHdrFtr:
 	case PTX_Section:
 		{
 			_closeBlock();
-			return true;
-		}
+			PT_AttrPropIndex api = pcr->getIndexAP();
+			const PP_AttrProp * pAP = NULL;
+			bool bHaveProp = m_pDocument->getAttrProp (api, &pAP);
 
-	case PTX_SectionHdrFtr:
-		{
-			_closeBlock();
+			if (bHaveProp && pAP)
+			{
+				const XML_Char *szValue = NULL;
+				if(pAP->getProperty("dom-dir", szValue))
+				{
+					if(!UT_stricmp("rtl",szValue))
+					{
+						m_eSectionDir = DO_RTL;
+					}
+					else
+					{
+						m_eSectionDir = DO_LTR;
+					}
+				}
+				else
+				{
+					m_eSectionDir = DO_UNSET;
+				}
+				
+			}
 			return true;
 		}
 
@@ -540,11 +803,84 @@ bool Text_Listener::populateStrux(PL_StruxDocHandle /*sdh*/,
 		{
 			_closeBlock();
 			m_bInBlock = true;
+
+			const XML_Char * szValue = NULL;
+
+			PT_AttrPropIndex api = pcr->getIndexAP();
+			const PP_AttrProp * pAP = NULL;
+			bool bHaveProp = m_pDocument->getAttrProp (api, &pAP);
+
+			m_bBreakExtra = false;
+
+			if (bHaveProp && pAP)
+			{
+				szValue = PP_evalProperty ("margin-top", 0, pAP, 0, m_pDocument, true);
+				if(szValue)
+				{
+					double inches = UT_convertToInches(szValue);
+					if (!m_bFirstWrite && (inches > 0.01))
+						m_pie->write(static_cast<const char *>(m_mbLineBreak),m_iLineBreakLen);
+				}
+				szValue = PP_evalProperty ("margin-bottom", 0, pAP, 0, m_pDocument, true);
+				if(szValue)
+				{
+					double inches = UT_convertToInches(szValue);
+					if (inches > 0.01)
+						m_bBreakExtra = true;
+				}
+			}
+
+			// in 16-bit encodings we sometimes have to issue LRM or
+			// RLM to indicate the dominant direction of the block
+			// (the actual insertion will be done in the subsequent
+			// call to _outputData(), since most often the marker is
+			// unnecessary
+			if(m_bUnicode)
+			{
+				if (bHaveProp && pAP)
+				{
+					szValue = NULL;
+					if(pAP->getProperty("dom-dir", szValue))
+					{
+						if(!UT_stricmp("rtl",szValue))
+						{
+							m_eDirMarkerPending = DO_RTL;
+						}
+						else
+						{
+							m_eDirMarkerPending = DO_LTR;
+						}
+					}
+					else if(m_eSectionDir != DO_UNSET)
+					{
+						m_eDirMarkerPending = m_eSectionDir;
+					}
+					else
+					{
+						m_eDirMarkerPending = m_eDocDir;
+					}
+				}
+			}
+			
 			return true;
 		}
 
+		// Be nice about these until we figure out what to do with 'em
+	case PTX_SectionTable:
+	case PTX_SectionCell:
+	case PTX_EndTable:
+	case PTX_EndCell:
+	case PTX_EndFrame:
+	case PTX_EndMarginnote:
+	case PTX_EndFootnote:
+	case PTX_SectionFrame:
+	case PTX_SectionMarginnote:
+	case PTX_SectionFootnote:
+	case PTX_EndEndnote:
+	    return true ;
+
 	default:
-		UT_ASSERT(0);
+		UT_ASSERT_NOT_REACHED();
 		return false;
 	}
 }
@@ -552,7 +888,7 @@ bool Text_Listener::populateStrux(PL_StruxDocHandle /*sdh*/,
 bool Text_Listener::change(PL_StruxFmtHandle /*sfh*/,
 								const PX_ChangeRecord * /*pcr*/)
 {
-	UT_ASSERT(0);						// this function is not used.
+	UT_ASSERT_NOT_REACHED();						// this function is not used.
 	return false;
 }
 
@@ -564,12 +900,12 @@ bool Text_Listener::insertStrux(PL_StruxFmtHandle /*sfh*/,
 																 PL_ListenerId /* lid */,
 																 PL_StruxFmtHandle /* sfhNew */))
 {
-	UT_ASSERT(0);						// this function is not used.
+	UT_ASSERT_NOT_REACHED();						// this function is not used.
 	return false;
 }
 
 bool Text_Listener::signal(UT_uint32 /* iSignal */)
 {
-	UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+  UT_ASSERT_NOT_REACHED();
 	return false;
 }
