@@ -29,6 +29,7 @@
 #include "fg_GraphicRaster.h"
 
 #include "pd_Document.h"
+#include "pd_Style.h"
 
 // abiword stuff
 #include "ut_xml.h"
@@ -39,6 +40,7 @@
 #include "ut_hash.h"
 #include "ut_vector.h"
 #include "ut_stack.h"
+#include "ut_math.h"
 
 #include "ut_debugmsg.h"
 
@@ -54,18 +56,18 @@ class ABI_EXPORT OO_Style
 {
 public:
   
-  OO_Style (const XML_Char ** props)
+  OO_Style (const XML_Char ** props, const PD_Style * pParentStyle)
     : m_bColBreakBefore (false), m_bPageBreakBefore (false)
   {
-    parse (props);
+    parse (props, pParentStyle);
   }
 
-  OO_Style (const OO_Style * other, const XML_Char ** props)
+  OO_Style (const OO_Style * other, const XML_Char ** props, PD_Style * pParentStyle)
     : m_bColBreakBefore (false), m_bPageBreakBefore (false)
   {
     if (other)
       *this = *other;
-    parse (props);
+    parse (props, pParentStyle);
   }
   
   ~OO_Style ()
@@ -93,11 +95,11 @@ public:
 
 private:
 
-  void parse (const XML_Char ** props)
+  void parse (const XML_Char ** props, const PD_Style * pParentStyle)
   {
     const XML_Char** p = props;   
     const XML_Char * val = NULL;
-    
+
     val = UT_getAttribute ("fo:text-align", props);
     if (val)
       if (!UT_strcmp(val, "end"))
@@ -130,12 +132,21 @@ private:
       m_bgcolor = UT_String_sprintf ("bgcolor: %s;", val);      
     
     val = UT_getAttribute("style:font-name", props);
-    if(val)
-      m_fontName = UT_String_sprintf ("font-face: %s;", val);
-    
+    if(val) 
+      m_fontName = UT_String_sprintf ("font-family: %s;", val);
+
     val = UT_getAttribute("fo:font-size", props);
-    if(val)
-      m_fontSize = UT_String_sprintf ("font-size: %s;", val);
+    if(val) {
+      if ((val[strlen(val)-1] == '%') && pParentStyle) {
+        // calculate font-size based on parent's 
+	const XML_Char * parentFontSize = NULL;
+        pParentStyle->getProperty("font-size", parentFontSize);
+        double fontSize = atoi(parentFontSize) * atoi(val) / 100.0;
+        m_fontSize = UT_String_sprintf ("font-size: %gpt;", rint(fontSize));
+      }
+      else
+        m_fontSize = UT_String_sprintf ("font-size: %s;", val);
+    }
     
     if (UT_getAttribute("fo:language", props) && UT_getAttribute("fo:country", props))
       m_lang = UT_String_sprintf ("lang: %s-%s;", UT_getAttribute("fo:language", props),
@@ -177,10 +188,18 @@ private:
     if(val)
       m_marginLeft = UT_String_sprintf ("margin-left: %s;", val);
     
+    val = UT_getAttribute ("fo:margin-top", props);
+    if(val)
+      m_marginTop = UT_String_sprintf ("margin-top: %s;", val);
+    
     val = UT_getAttribute ("fo:margin-right", props);
     if(val)
       m_marginRight = UT_String_sprintf ("margin-right: %s;", val);
   
+    val = UT_getAttribute ("fo:margin-bottom", props);
+    if(val)
+      m_marginBottom = UT_String_sprintf ("margin-bottom: %s;", val);
+    
     val = UT_getAttribute ("style:line-height-at-least", props);
     if (val)
       m_lineHeight = UT_String_sprintf ("line-height: %s+;", val);
@@ -249,7 +268,9 @@ private:
     APPEND_STYLE(m_textPos);
     APPEND_STYLE(m_textDecoration);
     APPEND_STYLE(m_marginLeft);
+    APPEND_STYLE(m_marginTop);
     APPEND_STYLE(m_marginRight);
+    APPEND_STYLE(m_marginBottom);
     APPEND_STYLE(m_lineHeight);
     APPEND_STYLE(m_keepWithNext);
     APPEND_STYLE(m_keepTogether);
@@ -276,7 +297,9 @@ private:
   UT_String m_textPos;
   UT_String m_textDecoration;
   UT_String m_marginLeft;
+  UT_String m_marginTop;
   UT_String m_marginRight;
+  UT_String m_marginBottom;
   UT_String m_lineHeight;
   UT_String m_keepWithNext;
   UT_String m_keepTogether;
@@ -351,8 +374,8 @@ UT_Confidence_t IE_Imp_OpenWriter_Sniffer::recognizeContents (const char * szBuf
 							      UT_uint32 iNumbytes)
 {
   // BOGUS - will identify any zip file, also contains null characters
-  static const char * magic = "PK     ";
-  UT_uint32 magic_len = strlen ( magic );
+  static const char magic[10] = {'P','K',0x03,0x04,0x14,'\0','\0','\0','\0','\0'};  
+  UT_uint32 magic_len = sizeof ( magic );
   
   if (iNumbytes < magic_len)
     return UT_CONFIDENCE_ZILCH;
@@ -391,7 +414,7 @@ void IE_Imp_OpenWriter::defineSimpleStyle (const UT_UTF8String & name, const XML
   if (!name.size() || !props)
     return;
   
-  OO_Style * style = new OO_Style (props);
+  OO_Style * style = new OO_Style (props, NULL);
   m_styleBucket.insert (name.utf8_str(), style);
 }
 
@@ -452,8 +475,6 @@ UT_Error IE_Imp_OpenWriter::importFile(const char * szFilename)
     return err;
   if ( UT_OK != (err = _handleStylesStream ()))
     return err;
-  if ( UT_OK != (err = _handleStylesStream ()))
-    return err;
   if ( UT_OK != (err = _handleContentStream ()))
     return err;
     
@@ -506,7 +527,7 @@ static UT_Error loadStream ( GsfInfile * oo,
 			     UT_ByteBuf & buf )
 {
   guint8 const *data = NULL;
-  size_t len = 0;
+  gsf_off_t len = 0;
   
   buf.truncate (0);
   GsfInput * input = gsf_infile_child_by_name(oo, stream);
@@ -538,7 +559,7 @@ static UT_Error parseStream ( GsfInfile * oo,
 			      UT_XML & parser )
 {
   guint8 const *data = NULL;
-  size_t len = 0;
+  gsf_off_t len = 0;
 
   GsfInput * input = gsf_infile_child_by_name(oo, stream);
 
@@ -735,8 +756,10 @@ public:
       }
       DELETEP(m_ooStyle);
     }
-    else if (!strcmp (name, "style:properties"))
-      m_ooStyle = new OO_Style (atts);
+    else if (!strcmp (name, "style:properties")) {
+      getDocument()->getStyle (m_parent.utf8_str(), &m_pParentStyle);
+      m_ooStyle = new OO_Style (atts, m_pParentStyle);
+    }
   } 
 
   virtual void endElement (const XML_Char * name)
@@ -774,9 +797,8 @@ public:
       m_name.clear ();
       m_parent.clear ();
       m_next.clear ();
+      DELETEP(m_ooStyle);
     }
-
-    DELETEP(m_ooStyle);
   }
   
   virtual void charData (const XML_Char * buffer, int length)
@@ -790,6 +812,7 @@ private:
   UT_UTF8String m_next;
   enum { CHARACTER, PARAGRAPH } m_type;
   OO_Style *m_ooStyle;
+  PD_Style *m_pParentStyle;
 };
 
 /*!
@@ -813,6 +836,7 @@ private:
   UT_UCS4String m_charData;
   bool m_bAcceptingText;
   bool m_bInSection;  
+  bool m_bSectionHasPara;
 
   UT_UTF8String m_curStyleName;
 
@@ -827,8 +851,8 @@ private:
 
 public:
   OpenWriter_ContentStream_Listener ( IE_Imp_OpenWriter * importer )
-    : OpenWriter_Stream_Listener ( importer ), m_bAcceptingText(false), m_bInSection(false), m_imgCnt(0),
-      m_row(0), m_col(0), m_cel(0)
+    : OpenWriter_Stream_Listener ( importer ), m_bAcceptingText(false), m_bInSection(false), m_bSectionHasPara(false), 
+      m_imgCnt(0), m_row(0), m_col(0), m_cel(0)
   {
   }
 
@@ -852,6 +876,7 @@ public:
 	props[2] = 0;
 	getDocument()->appendStrux(PTX_Section, (const XML_Char**)props);	
 	m_bInSection = true;
+	m_bSectionHasPara = false;
       }
     else if (!UT_strcmp(name, "text:p" ) || !UT_strcmp(name, "text:h" ))
       {
@@ -859,6 +884,7 @@ public:
 	  {
 	      getDocument()->appendStrux(PTX_Section, NULL);
 	      m_bInSection = true;
+	      m_bSectionHasPara = false;
 	  }
 	const XML_Char * oo_sty = UT_getAttribute ("text:style-name", atts);
 	const OO_Style * abi_sty = _mapStyleObj (oo_sty);
@@ -889,6 +915,7 @@ public:
 	else
 	  getDocument()->appendStrux(PTX_Block, NULL);
 	m_bAcceptingText = true;
+	m_bSectionHasPara = true;
       }
     else if (!UT_strcmp(name, "text:span"))
       {
@@ -945,7 +972,14 @@ public:
 	  {
 	      getDocument()->appendStrux(PTX_Section, NULL);
 	      m_bInSection = true;
+	      m_bSectionHasPara = false;
 	  }
+	// FIXME rob: workaround for #6725 "AbiWord Crashes Importing OpenWriter 1.1 Document Containing Table"
+	if (!m_bSectionHasPara)
+	  {
+	      getDocument()->appendStrux(PTX_Block, NULL);
+	      m_bSectionHasPara = true;
+ 	  }
 	_openTable (atts);
       }
     else if (!UT_strcmp(name, "table:table-column"))
@@ -1271,7 +1305,7 @@ private:
       return;
     UT_uint32 k;
     UT_uint32 end = m_vecInlineFmt.getItemCount();
-    for (k=end; k>=start; k--)
+    for (k=end; k>=static_cast<UT_uint32>(start); k--)
       {
 	XML_Char * p = const_cast<XML_Char*>((const XML_Char *)m_vecInlineFmt.getNthItem(k-1));
 	m_vecInlineFmt.deleteNthItem(k-1);
