@@ -30,10 +30,18 @@
 #include "fg_GraphicRaster.h"
 #include "ut_debugmsg.h"
 #include "xap_Module.h"
+#include "ut_assert.h"
 
 /*******************************************************************/
 /*******************************************************************/
 
+/* GDIPLUS interface */
+bool isGDIPlusAvailable ();
+UT_Error GDIconvertGraphic (UT_ByteBuf * pBB, UT_ByteBuf* pBBOut);
+void  shutDownGDIPlus ();
+
+
+
 static void _write_png( png_structp png_ptr, 
 		        png_bytep data, 
 		        png_size_t length )
@@ -56,8 +64,7 @@ static void CreateBMPFile(HWND hwnd, UT_ByteBuf & pBB, PBITMAPINFO pbi,
   BITMAPFILEHEADER hdr;       // bitmap file-header 
   PBITMAPINFOHEADER pbih;     // bitmap info-header 
   LPBYTE lpBits;              // memory pointer 	
-  DWORD dwTmp; 
-
+  
   if (!hBMP) return;
   
   pbih = (PBITMAPINFOHEADER) pbi; 
@@ -220,6 +227,14 @@ private:
     PBITMAPINFO	bi;
     UT_ByteBuf bBufBMP;
     UT_Error err;	
+	bool bIsMetaFile = false;
+
+	/* If the system has GDI+, use it*/
+	if (isGDIPlusAvailable())
+	{
+		m_pBB = new UT_ByteBuf();
+		return GDIconvertGraphic(pBB, m_pBB);		
+	}
 
     // We need to store the incoming bytebuffer in a Windows global heap	
     size_t nBlockLen = pBB->getLength();   	
@@ -241,28 +256,45 @@ private:
 
     stream->Release();
     GlobalFree(hG);
+
+	// IPicture interface cannot process old metafiles. That's bad since
+	// is the format used by Visio, Excel and other Microsoft tools 
+	// For these files we can use the native Metafile API functions
+	if (!pPicture)
+	{
+		const UT_Byte * pFile= pBB->getPointer(0);
+
+		if  (nBlockLen>4 &&			
+			((pFile[0]==0 || pFile[0]==0x01) && // Check file header
+			pFile[1]==0x00 && pFile[2]==0x9 && pFile[3]==0))
+			bIsMetaFile=true;
+	}
     
-    if (!SUCCEEDED(hr) || !pPicture)
+    if (bIsMetaFile==false && (!SUCCEEDED(hr) || !pPicture))
       {
 	return UT_IE_UNKNOWNTYPE;
       }
 
-    pPicture->get_Handle((unsigned int*)&hB);
+	HWND hWnd = GetDesktopWindow();
+	if (pPicture)
+	{
+		pPicture->get_Handle((unsigned int*)&hB);
     
-    hBitmap = (HBITMAP)CopyImage(hB,IMAGE_BITMAP,0,0,LR_COPYRETURNORG);
+		hBitmap = (HBITMAP)CopyImage(hB,IMAGE_BITMAP,0,0,LR_COPYRETURNORG);    							   		
     
-    HWND hWnd = GetDesktopWindow();
+		// Create a BMP file from a BITMAP	
+		bi = CreateBitmapInfoStruct(hBitmap);						
+		CreateBMPFile(hWnd, bBufBMP, bi, hBitmap, GetDC(hWnd));
+		LocalFree ((HLOCAL)bi);
     
-    // Create a BMP file from a BITMAP	
-    bi = CreateBitmapInfoStruct(hBitmap);						
-    CreateBMPFile(hWnd, bBufBMP, bi, hBitmap, GetDC(hWnd));
-    LocalFree ((HLOCAL)bi);
+		InitializePrivateClassData();
     
-    InitializePrivateClassData();
-    
-    /* Read Header Data */
-    err = Read_BMP_Header(&bBufBMP);
-	
+		/* Read Header Data */
+		err = Read_BMP_Header(&bBufBMP);
+	}	
+	else
+		err=UT_IE_BOGUSDOCUMENT;
+		
 	/* 
 		It's not a bitmap, then we have to rendered it into a device
 		context and get a bitmap from there. Case wmf graphics
@@ -271,7 +303,7 @@ private:
 	{
 		if (err!=UT_IE_BOGUSDOCUMENT) 
 		{
-			pPicture->Release();
+			if (pPicture) pPicture->Release();
 			return err;		
 		}
 		
@@ -284,13 +316,9 @@ private:
 		HBITMAP hBit;
 		HBITMAP hOld;
 		BITMAPINFO bmi; 		
-		HDC hWndDC = GetDC(hWnd);
-		HDC	hMemDC = CreateCompatibleDC(hWndDC);
-		HBRUSH hBrush = (HBRUSH)GetCurrentObject(hMemDC, OBJ_BRUSH);
+		HDC	hMemDC = CreateCompatibleDC(0);
+		HBRUSH hBrush = (HBRUSH)GetCurrentObject(hMemDC, OBJ_BRUSH);		
 		
-		pPicture->get_Width (&nWidth);
-		pPicture->get_Height(&nHeight);
-
 		bmi.bmiHeader.biSize = sizeof(BITMAPINFOHEADER); 	
 		bmi.bmiHeader.biWidth = nScaleToWidth;
 		bmi.bmiHeader.biHeight = nScaleToHeight;
@@ -304,8 +332,7 @@ private:
 		bmi.bmiHeader.biClrUsed = 0; // we are not using palette
 			
 		hBit = CreateDIBSection(hMemDC,&bmi,DIB_RGB_COLORS,(void**)&imagedata,0,0);						
-		hOld = (HBITMAP) SelectObject(hMemDC, hBit);			
-
+		hOld = (HBITMAP) SelectObject(hMemDC, hBit);				
 		
 		rect.left = 0;
         rect.top = nScaleToHeight;
@@ -313,31 +340,67 @@ private:
         rect.bottom = 0;
 
 		FillRect(hMemDC, &rect,  hBrush);
-		pPicture->Render(hMemDC, 0,0,  nScaleToWidth,	nScaleToHeight, 0,  nHeight, 
-				nWidth, -nHeight, &rc);	
+
+		if (!bIsMetaFile)
+		{
+			pPicture->get_Width (&nWidth);
+			pPicture->get_Height(&nHeight);
+			pPicture->Render(hMemDC, 0,0,  nScaleToWidth,	nScaleToHeight, 0,  nHeight, 
+				nWidth, -nHeight, &rc);			
+		}
+		else
+		{	
+			char szTempfile[2048];
+			UT_tmpnam(szTempfile);
+			pBB->writeToFile(szTempfile);
+
+			// Unfortunally there is no way to pass the data tru memory			
+			HMETAFILE hemf = GetMetaFile(szTempfile); 
+
+			if (hemf)
+			{
+				//SetMapMode(hMemDC, MM_TEXT);
+				int nMode = SetMapMode(hMemDC, MM_ISOTROPIC);
+				//SetWindowExtEx
+				//SetViewportExtEx(hMemDC, nScaleToWidth,nScaleToHeight, NULL);
+				//SetViewportOrgEx(hMemDC, 0,0, NULL);
+
+				SetMapMode(hMemDC, MM_ANISOTROPIC);
+				SetWindowOrgEx(hMemDC, 0, 0, NULL);
+				SetWindowExtEx(hMemDC, nScaleToHeight, nScaleToWidth, NULL);
+				SetViewportOrgEx(hMemDC, 0,0,NULL);
+				SetViewportExtEx(hMemDC, nScaleToHeight, nScaleToWidth, NULL);
+
+				PlayMetaFile(hMemDC, hemf); 
+				DeleteMetaFile(hemf);
+				SetMapMode(hMemDC, nMode);
+				//
+			}
+			
+			unlink(szTempfile);
+		}
 		
 		hBit =  (HBITMAP)SelectObject(hMemDC, hOld);
 		
 		bi =  CreateBitmapInfoStruct(hBit);						
 		CreateBMPFile(hWnd, bBufBMP, &bmi, hBit, hMemDC);
 		LocalFree ((HLOCAL)bi);
-
 		
 		DeleteDC(hMemDC);
-		DeleteDC(hWndDC);
-	    DeleteObject(hBrush); 
+		DeleteObject(hBrush); 
 		DeleteObject(hBit);	  
     
 		err = Read_BMP_Header(&bBufBMP);
 		if (err) 
 		{
-			pPicture->Release();
+			if (pPicture) pPicture->Release();
 			return err;				
 		}
 		
 	}
 
-	pPicture->Release();
+
+	if (pPicture) pPicture->Release();
 
 
     if ((err = Initialize_PNG()))
