@@ -739,15 +739,15 @@ void s_LaTeX_Listener::_openSpan(PT_AttrPropIndex api)
 			}
 		}
 		
-		XML_Char* pszColor = NULL;
-		pAP->getProperty("color", (const XML_Char*) pszColor);
+		const XML_Char* pszColor = NULL;
+		pAP->getProperty("color", pszColor);
 		if (pszColor)
 		  {
-		    if ((0 != UT_strcmp("000000", (const XML_Char*) pszColor)) &&
-			(0 != UT_strcmp("000000", (const XML_Char*) pszColor)))
+		    if ((0 != UT_strcmp("000000", pszColor)) &&
+			(0 != UT_strcmp("000000", pszColor)))
 		      {
  		 	UT_String szColor;
-			_convertColor(szColor,(char*)pszColor);
+			_convertColor(szColor,(const char*)pszColor);
 			m_pie->write("\\textcolor[rgb]{");
 			m_pie->write(szColor);
 			m_pie->write("}{");
@@ -756,16 +756,16 @@ void s_LaTeX_Listener::_openSpan(PT_AttrPropIndex api)
 		      m_pie->write("{");
 		  }
 		
-		XML_Char* pszBgColor = NULL;
-		pAP->getProperty("bgcolor", (const XML_Char*) pszBgColor);
+		const XML_Char* pszBgColor = NULL;
+		pAP->getProperty("bgcolor", pszBgColor);
 
 		if (pszBgColor)
 		{
-		  if ((0 != UT_strcmp("000000", (const XML_Char*) pszBgColor)) &&
-		      (0 != UT_strcmp("transparent", (const XML_Char*) pszBgColor)))
+		  if ((0 != UT_strcmp("000000", pszBgColor)) &&
+		      (0 != UT_strcmp("transparent", pszBgColor)))
 		    {
 		      UT_String szColor;
-		      _convertColor(szColor,(char*)pszBgColor);
+		      _convertColor(szColor,(const char*)pszBgColor);
 		      m_pie->write("\\colorbox[rgb]{");
 		      m_pie->write(szColor);
 		      m_pie->write("}{");
