@@ -377,25 +377,8 @@ void IE_Imp_WordPerfect::insertText(const UCSString &text)
 void IE_Imp_WordPerfect::insertLineBreak()
 {
 	if (m_bHdrFtrOpenCount) return; // HACK
-    /*UT_DEBUGMSG(("AbiWordPerfect: insertBreak(breakType: %d\n", breakType));
-      
-    switch (breakType)
-    {
-		case WPX_PAGE_BREAK:
-			{
-				UT_UCS4Char ucs = UCS_FF;
-				X_CheckDocumentError(appendSpan(&ucs,1));			
-			}
-			break;
-		case  WPX_COLUMN_BREAK:
-			{
-				UT_UCS4Char ucs = UCS_VTAB;
-				X_CheckDocumentError(appendSpan(&ucs,1));
-			}
-			break;
-		default:
-			break;
-    }*/
+	UT_UCSChar ucs = UCS_LF;
+	X_CheckDocumentError(appendSpan(&ucs,1));
 }
 
 void IE_Imp_WordPerfect::defineOrderedListLevel(const int listID, const guint16 level, const WPXNumberingType listType, 
