@@ -145,6 +145,7 @@ wvInitCHPFromIstd (CHP * achp, U16 istdBase, STSH * stsh)
 			    wvApplyCHPXFromBucket (achp,
 						   &(stsh->std[istdBase].
 						     grupe[0].chpx), stsh);
+				strncpy(achp->stylename,stsh->std[istdBase].xstzName, sizeof(achp->stylename));
 			    break;
 			}
 		  }
@@ -272,6 +273,8 @@ wvInitCHP (CHP * item)
     item->hpsBidi = 0;
     item->icoBidi = 0;
     item->lidBidi = 0;
+
+	item->stylename[0] = 0;
 }
 
 void
@@ -379,7 +382,9 @@ wvCopyCHP (CHP * dest, CHP * src)
     dest->ftcBidi = src->ftcBidi;
     dest->hpsBidi = src->hpsBidi;
     dest->icoBidi = src->icoBidi;
-    dest->lidBidi = src->lidBidi; 
+    dest->lidBidi = src->lidBidi;
+
+	strcpy(dest->stylename,src->stylename);
 }
 
 /*
@@ -656,47 +661,66 @@ wvUpdateCHPXBucket (UPXF * src)
  */
 
 int
-wvAssembleSimpleCHP (wvVersion ver, CHP * achp, U32 fc, CHPX_FKP * fkp,
+wvAssembleSimpleCHP (wvVersion ver, CHP * achp, const PAP * apap, U32 fc, CHPX_FKP * fkp,
 		     STSH * stsh)
 {
     CHPX *chpx;
-    int index, i;
+    int index;
     UPXF upxf;
     int ret = 0;
     U16 tistd;
 
-    /* initialize CHP to para's stylesheet character properties
-       * this should have resolved all the other stylesheet dependencies
+	
+    /* initialize CHP to para's stylesheet character properties this
+       * should have resolved all the other stylesheet dependencies
        * for us, when the stsh's were initialized. */
 
-    /* before this function was called, achp->istd should have
-       * been set to the current paragraph properties' stylesheet */
-    tistd = achp->istd;
-    wvInitCHPFromIstd (achp, achp->istd, stsh);
-    achp->istd = tistd;
+	wvInitCHPFromIstd (achp, apap->istd, stsh);
+	/* having done this, we want to set the achp->istd to nil, since
+    any char istd value stored in the para style is not applicable
+    (its a para style */
+	achp->istd = istdNil;
+	tistd = istdNil;
+	
+ apply_chpx:
+	/* get CHPX */
+	if(fkp)
+	{
+		/* the PAPX version of the function only looks at rgfc's, which are
+		 * the same for CHPX and PAPX FKPs, so we'll reuse the function */
+		index = wvGetIndexFCInFKP_PAPX ((PAPX_FKP *) fkp, fc);
 
-    /*index is the i in the text above */
-    /* the PAPX version of the function only looks at rgfc's, which are
-       * the same for CHPX and PAPX FKPs, so we'll reuse the function */
-    index = wvGetIndexFCInFKP_PAPX ((PAPX_FKP *) fkp, fc);
+		wvTrace (("index is %d, using %d\n", index, index - 1));
 
-    wvTrace (("index is %d, using %d\n", index, index - 1));
+		chpx = &(fkp->grpchpx[index - 1]);
 
-    /* get CHPX */
-    chpx = &(fkp->grpchpx[index - 1]);
+		/* apply CHPX from FKP */
+		if ((chpx) && (chpx->cbGrpprl > 0))
+		{
+			ret = 1;
+			/* for (i = 0; i < chpx->cbGrpprl; i++) */
+			upxf.cbUPX = chpx->cbGrpprl;
+			upxf.upx.chpx.grpprl = chpx->grpprl;
+			if (ver == WORD8)
+				wvAddCHPXFromBucket (achp, &upxf, stsh);
+			else
+				wvAddCHPXFromBucket6 (achp, &upxf, stsh);
+		}
 
-    /* apply CHPX from FKP */
-    if ((chpx) && (chpx->cbGrpprl > 0))
-      {
-	  ret = 1;
-	  /* for (i = 0; i < chpx->cbGrpprl; i++) */
-	  upxf.cbUPX = chpx->cbGrpprl;
-	  upxf.upx.chpx.grpprl = chpx->grpprl;
-	  if (ver == WORD8)
-	      wvAddCHPXFromBucket (achp, &upxf, stsh);
-	  else
-	      wvAddCHPXFromBucket6 (achp, &upxf, stsh);
-      }
+		if(achp->istd < stsh->Stshi.cstd)
+			strncpy(achp->stylename,stsh->std[achp->istd].xstzName, sizeof(achp->stylename));
+
+		if(achp->istd != tistd)
+		{
+			/* the chpx contained instruction to apply character
+			   style: we have to start all over again, since we init
+			   the chp from the wrong (paragraph) style */
+			tistd = achp->istd;
+			wvInitCHPFromIstd (achp, achp->istd, stsh);
+			goto apply_chpx;
+		}
+	}
+	
     return (ret);
 }
 
@@ -714,7 +738,8 @@ wvGetCHPX (wvVersion ver, CHPX * item, U8 * page, U16 * pos)
     else
 	item->grpprl = NULL;
 
-    item->istd = 0;		/* I have no idea what to set this to... */
+    item->istd = 0;		/* I have no idea what to set this to... --
+						   nothing; the istd is contained in the grpprl*/
 
     for (i = 0; i < item->cbGrpprl; i++)
 	wvTrace (("chpx byte is %x\n", item->grpprl[i]));
